@@ -3,8 +3,11 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox/fx.h>
-#include <fox/FXPNGIcon.h>
+#include <fox-1.2/fx.h>
+#include <fox-1.2/FXPNGIcon.h>
+#if defined(linux)
+#include <mntent.h>
+#endif
 
 #include "icons.h"
 #include "DirList.h"
@@ -23,25 +26,29 @@
 #define MAXPATHLEN 1024
 #endif
 
-// Interval between refreshes
+// Interval between mounts read (ms)
+#define MOUNTSINTERVAL		65000
+
+// Interval between refreshes (ms)
 #define REFRESHINTERVAL     1000
-#define REFRESHINTERVALLONG 15000
 
 // File systems not supporting mod-time, refresh every nth time
 #define REFRESHFREQUENCY    32
 
-// Time interval before expanding a folder
+// Time interval before expanding a folder (ms)
 #define EXPANDINTERVAL		500
 
+extern FXMainWindow *mainWindow;
 extern FXbool ask_before_copy;
 
-FXPNGIcon  *locked_folder;          // Locked folder icon
-TreeItem *prevSelItem;
 
 #if defined(linux)
 extern FXStringDict* devices;
+extern FXStringDict* mounts;
+extern FXbool mount_warn;
 #endif
 
+
 // Object implementation
 FXIMPLEMENT(DirItem,FXTreeItem,NULL,0)
 
@@ -50,7 +57,8 @@ FXIMPLEMENT(DirItem,FXTreeItem,NULL,0)
 // Map
 FXDEFMAP(DirList) DirListMap[]={
                                    FXMAPFUNC(SEL_DRAGGED,0,DirList::onDragged),
-                                   FXMAPFUNC(SEL_TIMEOUT,DirList::ID_REFRESH,DirList::onRefresh),
+                                   FXMAPFUNC(SEL_TIMEOUT,DirList::ID_REFRESHTIMER,DirList::onRefreshTimer),
+                                   FXMAPFUNC(SEL_TIMEOUT,DirList::ID_MOUNTSTIMER,DirList::onMountsTimer),
                                    FXMAPFUNC(SEL_TIMEOUT,DirList::ID_EXPANDTIMER,DirList::onExpandTimer),
                                    FXMAPFUNC(SEL_DND_ENTER,0,DirList::onDNDEnter),
                                    FXMAPFUNC(SEL_DND_LEAVE,0,DirList::onDNDLeave),
@@ -93,7 +101,7 @@ FXIMPLEMENT(DirList,FXTreeList,DirListMap,ARRAYNUMBER(DirListMap))
 DirList::DirList()
 {
     flags|=FLAG_ENABLED|FLAG_DROPTARGET;
-    refresh=NULL;
+    refreshtimer=NULL;
     expandtimer=NULL;
     counter=0;
     associations=NULL;
@@ -101,9 +109,10 @@ DirList::DirList()
 }
 
 
+
 // Directory List Widget
 DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
-        FXTreeList(p,0,tgt,sel,opts,x,y,w,h),pattern("*")
+        FXTreeList(p,tgt,sel,opts,x,y,w,h),pattern("*")
 {
     flags|=FLAG_ENABLED|FLAG_DROPTARGET;
     associations=NULL;
@@ -113,13 +122,18 @@ DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x
     mini_app=new FXPNGIcon(getApp(),miniapp);
     locked_folder=new FXPNGIcon(getApp(),minifolderlocked);
     harddiskicon=new FXPNGIcon(getApp(),harddisk);
+    nfsicon=new FXPNGIcon(getApp(),nfsdrive);
+    floppyicon=new FXPNGIcon(getApp(),floppy);
+    cdromicon=new FXPNGIcon(getApp(),cdrom);
+    zipicon=new FXPNGIcon(getApp(),zip);
     linkicon=new FXPNGIcon(getApp(),minilink);
     matchmode=FILEMATCH_FILE_NAME|FILEMATCH_NOESCAPE;
     if(!(options&DIRLIST_NO_OWN_ASSOC))
         associations=new FileDict(getApp());
     sortfunc=(FXTreeListSortFunc)cmpFName;
-    refresh=NULL;
+    refreshtimer=NULL;
     expandtimer=NULL;
+	mountstimer=NULL;
     dropaction=DRAG_MOVE;
     counter=0;
     prevSelItem = NULL;
@@ -129,13 +143,64 @@ DirList::DirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x
 // Create the directory list
 void DirList::create()
 {
+#if defined(linux)
+    FILE *fstab=setmntent("/etc/fstab","r");
+    struct mntent *mnt;
+	struct stat statbuf;
+    if(fstab)
+    {
+        while((mnt=getmntent(fstab)))
+        {
+            if(strcmp(mnt->mnt_type,MNTTYPE_IGNORE) && strcmp(mnt->mnt_type,MNTTYPE_SWAP) && strcmp(mnt->mnt_type,"proc") && strcmp(mnt->mnt_dir,"/"))
+            {
+                if(!strncmp(mnt->mnt_fsname,"/dev/fd",7))
+                    devices->insert(mnt->mnt_dir,"floppy");
+                else if (!strncmp(mnt->mnt_type,"iso",3))
+                    devices->insert(mnt->mnt_dir,"cdrom");
+                else if (!strncmp(mnt->mnt_fsname,"/dev/zip",8))
+                    devices->insert(mnt->mnt_dir,"zip");
+                else if (!strcmp(mnt->mnt_type,"nfs"))
+                    devices->insert(mnt->mnt_dir,"nfsdisk");
+                else if (!strcmp(mnt->mnt_type,"smbfs"))
+                    devices->insert(mnt->mnt_dir,"smbdisk");
+                else
+                    devices->insert(mnt->mnt_dir,"harddisk");
+            }
+        }
+        endmntent(fstab);
+    }
+    
+	// To mark mount points that are down
+    FILE *mtab=setmntent("/etc/mtab","r");
+	char mttype[16];
+	if(mtab)
+    {
+        while((mnt=getmntent(mtab)))
+		{
+			if (mtlstat(mnt->mnt_dir,&statbuf)==-1)
+			{
+				strcpy(mttype,"down");
+				if (mount_warn)
+					MessageBox::warning(mainWindow,MBOX_OK,_("Warning"),_("Mount point %s is not responding..."),mnt->mnt_dir);									
+			}
+			else
+				strcpy(mttype,mnt->mnt_type);	
+			mounts->insert(mnt->mnt_dir,mttype);
+
+		}
+        endmntent(mtab);
+    }
+#endif
+
     FXTreeList::create();
     if(!deleteType)
         deleteType=getApp()->registerDragType(deleteTypeName);
     if(!urilistType)
         urilistType=getApp()->registerDragType(urilistTypeName);
-    if(!refresh)
-        refresh=getApp()->addTimeout(REFRESHINTERVAL,this,ID_REFRESH);
+    if(!refreshtimer)
+        refreshtimer=getApp()->addTimeout(this,ID_REFRESHTIMER,REFRESHINTERVAL);
+    if(!mountstimer)
+        mountstimer=getApp()->addTimeout(this,ID_MOUNTSTIMER,MOUNTSINTERVAL);
     dropEnable();
     open_folder->create();
     closed_folder->create();
@@ -143,44 +208,22 @@ void DirList::create()
     mini_app->create();
     locked_folder->create();
     harddiskicon->create();
+    nfsicon->create();
+    floppyicon->create();
+    cdromicon->create();
+    zipicon->create();
     linkicon->create();
-    scanRootDir(FALSE);
+    
+	// Scan root directory
+	scanRootDir(FALSE);
+
+    // Expand root item
+	TreeItem* item=getitem(ROOTDIR);
+	if (item)
+		expandTree(item,TRUE);
 }
 
 
-// Detach disconnects the icons
-void DirList::detach()
-{
-    FXTreeList::detach();
-    if(refresh)
-        refresh=getApp()->removeTimeout(refresh);
-    if(expandtimer)
-        expandtimer=getApp()->removeTimeout(expandtimer);
-    open_folder->detach();
-    closed_folder->detach();
-    mini_doc->detach();
-    mini_app->detach();
-    locked_folder->detach();
-    deleteType=0;
-    urilistType=0;
-}
-
-
-// Destroy zaps the icons
-void DirList::destroy()
-{
-    FXTreeList::destroy();
-    if(refresh)
-        refresh=getApp()->removeTimeout(refresh);
-    if(expandtimer)
-        expandtimer=getApp()->removeTimeout(expandtimer);
-    open_folder->destroy();
-    closed_folder->destroy();
-    mini_doc->destroy();
-    mini_app->destroy();
-    locked_folder->destroy();
-}
-
 // Expand folder tree when hovering long over a folder
 long DirList::onExpandTimer(FXObject* sender,FXSelector sel,void* ptr)
 {
@@ -211,7 +254,7 @@ long DirList::onExpandTimer(FXObject* sender,FXSelector sel,void* ptr)
         sortChildItems(item);
 
     // Set open timer
-    expandtimer=getApp()->addTimeout(EXPANDINTERVAL,this,ID_EXPANDTIMER);
+    expandtimer=getApp()->addTimeout(this,ID_EXPANDTIMER,EXPANDINTERVAL);
 
     return 1;
 
@@ -383,7 +426,7 @@ long DirList::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr)
         expandtimer=getApp()->removeTimeout(expandtimer);
 
     // Start autoscrolling
-    if(startAutoScroll(event->win_x,event->win_y,FALSE))
+    if(startAutoScroll(event,FALSE))
         return 1;
 
     // Give base class a shot
@@ -407,7 +450,7 @@ long DirList::onDNDMotion(FXObject* sender,FXSelector sel,void* ptr)
             dropaction=inquireDNDAction();
 
             // Set open up timer
-            expandtimer=getApp()->addTimeout(EXPANDINTERVAL,this,ID_EXPANDTIMER);
+            expandtimer=getApp()->addTimeout(this,ID_EXPANDTIMER,EXPANDINTERVAL);
 
             // See if this is writable
             if(FXFile::isWritable(dropdirectory))
@@ -585,7 +628,7 @@ long DirList::onDNDRequest(FXObject* sender,FXSelector sel,void* ptr)
         if(!dragfiles.empty())
         {
             len=dragfiles.length();
-            FXMEMDUP(&data,FXuchar,dragfiles.text(),len);
+      		FXMEMDUP(&data,dragfiles.text(),FXuchar,len);
             setDNDData(FROM_DRAGNDROP,event->target,data,len);
         }
         return 1;
@@ -711,9 +754,9 @@ long DirList::onCmdToggleHidden(FXObject*,FXSelector,void*)
 long DirList::onUpdToggleHidden(FXObject* sender,FXSelector,void*)
 {
     if(showHiddenFiles())
-        sender->handle(this,MKUINT(ID_CHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
-        sender->handle(this,MKUINT(ID_UNCHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
     return 1;
 }
 
@@ -730,9 +773,9 @@ long DirList::onCmdShowHidden(FXObject*,FXSelector,void*)
 long DirList::onUpdShowHidden(FXObject* sender,FXSelector,void*)
 {
     if(showHiddenFiles())
-        sender->handle(this,MKUINT(ID_CHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
-        sender->handle(this,MKUINT(ID_UNCHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
     return 1;
 }
 
@@ -749,9 +792,9 @@ long DirList::onCmdHideHidden(FXObject*,FXSelector,void*)
 long DirList::onUpdHideHidden(FXObject* sender,FXSelector,void*)
 {
     if(!showHiddenFiles())
-        sender->handle(this,MKUINT(ID_CHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
-        sender->handle(this,MKUINT(ID_UNCHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
     return 1;
 }
 
@@ -768,9 +811,9 @@ long DirList::onCmdToggleFiles(FXObject*,FXSelector,void*)
 long DirList::onUpdToggleFiles(FXObject* sender,FXSelector,void*)
 {
     if(showFiles())
-        sender->handle(this,MKUINT(ID_CHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
-        sender->handle(this,MKUINT(ID_UNCHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
     return 1;
 }
 
@@ -787,9 +830,9 @@ long DirList::onCmdShowFiles(FXObject*,FXSelector,void*)
 long DirList::onUpdShowFiles(FXObject* sender,FXSelector,void*)
 {
     if(showFiles())
-        sender->handle(this,MKUINT(ID_CHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
-        sender->handle(this,MKUINT(ID_UNCHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
     return 1;
 }
 
@@ -806,9 +849,9 @@ long DirList::onCmdHideFiles(FXObject*,FXSelector,void*)
 long DirList::onUpdHideFiles(FXObject* sender,FXSelector,void*)
 {
     if(!showFiles())
-        sender->handle(this,MKUINT(ID_CHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
-        sender->handle(this,MKUINT(ID_UNCHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
     return 1;
 }
 
@@ -826,7 +869,7 @@ long DirList::onCmdSetPattern(FXObject*,FXSelector,void* ptr)
 // Update pattern
 long DirList::onUpdSetPattern(FXObject* sender,FXSelector,void*)
 {
-    sender->handle(this,MKUINT(FXWindow::ID_SETVALUE,SEL_COMMAND),(void*)pattern.text());
+    sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SETVALUE),(void*)pattern.text());
     return 1;
 }
 
@@ -847,7 +890,7 @@ long DirList::onCmdSortReverse(FXObject*,FXSelector,void*)
 long DirList::onUpdSortReverse(FXObject* sender,FXSelector,void* ptr)
 {
     FXuint msg=(sortfunc==(FXTreeListSortFunc)cmpRName)?ID_CHECK:ID_UNCHECK;
-    sender->handle(this,MKUINT(msg,SEL_COMMAND),ptr);
+    sender->handle(this,FXSEL(SEL_COMMAND,msg),ptr);
     return 1;
 }
 
@@ -859,7 +902,7 @@ long DirList::onClosed(FXObject*,FXSelector,void* ptr)
 {
     DirItem *item=(DirItem*)ptr;
     if(item->state&DirItem::FOLDER)
-        return target && target->handle(this,MKUINT(message,SEL_CLOSED),ptr);
+        return target && target->handle(this,FXSEL(SEL_CLOSED,message),ptr);
 
     return 1;
 }
@@ -870,7 +913,7 @@ long DirList::onOpened(FXObject*,FXSelector,void* ptr)
 {
     DirItem *item=(DirItem*)ptr;
     if(item->state&DirItem::FOLDER)
-        return target && target->handle(this,MKUINT(message,SEL_OPENED),ptr);
+        return target && target->handle(this,FXSEL(SEL_OPENED,message),ptr);
     return 1;
 }
 
@@ -920,24 +963,79 @@ long DirList::onCollapsed(FXObject* sender,FXSelector sel,void* ptr)
 }
 
 
-// Refresh
-long DirList::onRefresh(FXObject*,FXSelector,void*)
+// To periodically scan /etc/mtab and detect down mount points
+long DirList::onMountsTimer(FXObject*,FXSelector,void*)
 {
-    FXbool changed;
-
-    // Not necessary???
-    // Only update if user is not interacting with the file list
-    //if(flags&FLAG_UPDATE)
-    //{
-    changed=scanRootDir(FALSE);
-    if(changed)
-        recalc();
-    counter=(counter+1)%REFRESHFREQUENCY;
-    //}
+#if defined(linux)
+    struct mntent *mnt;
+	struct stat statbuf;
+	FXchar mttype[16];
+	
+	FXStringDict* tmpdict = new FXStringDict();
+    FILE *mtab=setmntent("/etc/mtab","r");
+    if(mtab)
+    {
+        while((mnt=getmntent(mtab)))
+		{
+			tmpdict->insert(mnt->mnt_dir,"");
+			
+			if (mtlstat(mnt->mnt_dir,&statbuf)==-1)
+			{
+				strcpy(mttype,"down");
+				if (mount_warn)
+					MessageBox::warning(this,MBOX_OK,_("Warning"),_("Mount point %s is not responding..."),mnt->mnt_dir);									
+			}
+			else
+				strcpy(mttype,mnt->mnt_type);		
+			
+			if (mounts->find(mnt->mnt_dir))
+				mounts->remove(mnt->mnt_dir);
+			mounts->insert(mnt->mnt_dir,mttype);
+			
+		}
+        endmntent(mtab);
+    }
+	
+	// Remove mount points that don't exist anymore
+	FXint s;
+	const FXchar *key, *data;
+    for (s = mounts->first(); s < mounts->size(); s = mounts->next(s))
+    {
+        key = mounts->key(s);
+        data = mounts->data(s);
+		if (!tmpdict->find(mounts->key(s)))
+			mounts->remove(mounts->key(s));
+		
+    }
+	delete tmpdict;	
+#endif
 
     // Reset timer again
-    refresh=getApp()->addTimeout(REFRESHINTERVAL,this,ID_REFRESH);
+    mountstimer=getApp()->addTimeout(this,ID_MOUNTSTIMER,MOUNTSINTERVAL);
+    return 0;
+}
 
+// Refresh with timer
+long DirList::onRefreshTimer(FXObject*,FXSelector,void*)
+{
+	if(flags&FLAG_UPDATE)
+	{
+    	FXbool changed=scanRootDir(FALSE);
+    	if(changed)
+        	recalc();		
+    	counter=(counter+1)%REFRESHFREQUENCY;
+	}
+
+    // Reset timer again
+    refreshtimer=getApp()->addTimeout(this,ID_REFRESHTIMER,REFRESHINTERVAL);
+    return 0;
+}
+
+// Force refresh
+long DirList::onRefresh(FXObject*,FXSelector,void*)
+{
+	scanRootDir(TRUE);
+	recalc();
     return 0;
 }
 
@@ -988,9 +1086,8 @@ FXbool DirList::scanRootDir(FXbool relist)
     // Item is directory; check regardless of children
     if((item->state&DirItem::FOLDER) && (item->state&DirItem::EXPANDED))
     {
-
         // Refresh subitems of root if necessary
-        if(stat(pathname,&info)==0)
+        if(statout(pathname,&info)==0)
         {
             filetime=FXMAX(info.st_mtime,info.st_ctime);
             if(relist || (item->date!=filetime) || ((filetime==0) && (counter==0)))
@@ -1022,7 +1119,6 @@ FXbool DirList::scanSubDir(DirItem *par,FXchar *pathname,FXbool relist)
 
     if(par->first)
     {
-
         // Build path prefix
         pathend=pathtail=pathname+strlen(pathname);
         if(!ISPATHSEP(*(pathtail-1)))
@@ -1031,24 +1127,23 @@ FXbool DirList::scanSubDir(DirItem *par,FXchar *pathname,FXbool relist)
         // Loop over contents
         for(item=(DirItem*)par->first; item; item=(DirItem*)item->next)
         {
-
             // Item is directory; check regardless of children
             if((item->state&DirItem::FOLDER) && (item->state&DirItem::EXPANDED))
             {
-
                 // Sub item path
                 strcpy(pathtail,item->label.text());
 
                 // Refresh subitems of item if necessary
-                if(stat(pathname,&info)==0)
+				if(statout(pathname,&info)==0)
                 {
                     filetime=FXMAX(info.st_mtime,info.st_ctime);
-                    if(relist || (item->date!=filetime) || ((filetime==0) && (counter==0)))
+                    //if(relist || (item->date!=filetime) || (counter==0))
+					if(relist || (item->date!=filetime) || ((filetime==0) && (counter==0)))
                     {
                         if(listSubDir(item,pathname))
                         {
-                            sortChildItems(item);
-                            changed=TRUE;
+                           sortChildItems(item);
+                           changed=TRUE;
                         }
                     }
                     item->date=filetime;
@@ -1094,7 +1189,6 @@ FXbool DirList::listSubDir(DirItem *par,FXchar *pathname)
     // Managed to open directory
     if(dirp)
     {
-
         // Insert a '/' if needed
         if(!ISPATHSEP(*(pathtail-1)))
             *pathtail++=PATHSEP;
@@ -1116,12 +1210,12 @@ FXbool DirList::listSubDir(DirItem *par,FXchar *pathname)
             strcpy(pathtail,name);
 
             // Get File info
-            if(lstat(pathname,&info)!=0)
+			if(lstatout(pathname,&info)!=0)
                 continue;
 
             // If its a link, get the file info
             islink=S_ISLNK(info.st_mode);
-            if(islink && stat(pathname,&info)!=0)
+			if(islink && statout(pathname,&info)!=0)
                 continue;
 
             // If it is not a directory, and not showing files and matching pattern skip it
@@ -1233,7 +1327,6 @@ fnd:
                 else
                     item->state&=~DirItem::SOCK;
 
-
                 // We can drag items
                 item->state|=DirItem::DRAGGABLE;
 
@@ -1282,10 +1375,38 @@ fnd:
 #if defined(linux)
                 // Devices have a specific icon
                 if(devices->find(pathname))
-                {
-                    item->closedIcon=harddiskicon;
-                    item->openIcon=harddiskicon;
-                }
+				{
+				 	if(!strcmp(devices->find(pathname),"harddisk"))
+                	{
+                    	item->closedIcon=harddiskicon;
+                    	item->openIcon=harddiskicon;
+                	}
+				 	else if(!strcmp(devices->find(pathname),"nfsdisk"))
+                	{
+                    	item->closedIcon=nfsicon;
+                    	item->openIcon=nfsicon;
+                	}
+				 	else if(!strcmp(devices->find(pathname),"smbdisk"))
+                	{
+                    	item->closedIcon=nfsicon;
+                    	item->openIcon=nfsicon;
+                	}
+                	else if(!strcmp(devices->find(pathname),"floppy"))
+                	{
+                    	item->closedIcon=floppyicon;
+                    	item->openIcon=floppyicon;
+                	}
+                	else if(!strcmp(devices->find(pathname),"cdrom"))
+                	{
+                    	item->closedIcon=cdromicon;
+                    	item->openIcon=cdromicon;
+					}
+                	else if(!strcmp(devices->find(pathname),"zip"))
+                	{
+                    	item->closedIcon=zipicon;
+                    	item->openIcon=zipicon;
+                	}
+				}
 #endif
 
                 // Symbolic links have a specific icon
@@ -1524,40 +1645,12 @@ void DirList::setMatchMode(FXuint mode)
 }
 
 
-// Save data
-void DirList::save(FXStream& store) const
-{
-    FXTreeList::save(store);
-    store << associations;
-    store << pattern;
-    store << matchmode;
-    store << closed_folder;
-    store << open_folder;
-    store << mini_doc;
-    store << mini_app;
-}
-
-
-// Load data
-void DirList::load(FXStream& store)
-{
-    FXTreeList::load(store);
-    store >> associations;
-    store >> pattern;
-    store >> matchmode;
-    store >> closed_folder;
-    store >> open_folder;
-    store >> mini_doc;
-    store >> mini_app;
-}
-
-
 // Cleanup
 DirList::~DirList()
 {
     clearItems();
-    if(refresh)
-        getApp()->removeTimeout(refresh);
+    if(refreshtimer)
+        getApp()->removeTimeout(refreshtimer);
     if(expandtimer)
         getApp()->removeTimeout(expandtimer);
     if(!(options&DIRLIST_NO_OWN_ASSOC))
@@ -1567,15 +1660,23 @@ DirList::~DirList()
     delete mini_doc;
     delete mini_app;
     delete harddiskicon;
+    delete nfsicon;
+    delete floppyicon;
+    delete cdromicon;
+    delete zipicon;
     delete linkicon;
+	delete locked_folder;
     associations=(FileDict*)-1;
     closed_folder=(FXPNGIcon*)-1;
     open_folder=(FXPNGIcon*)-1;
     mini_doc=(FXPNGIcon*)-1;
     mini_app=(FXPNGIcon*)-1;
     harddiskicon=(FXPNGIcon*)-1;
+    nfsicon=(FXPNGIcon*)-1;
     linkicon=(FXPNGIcon*)-1;
-    refresh=(FXTimer*)-1;
+	locked_folder=(FXPNGIcon*)-1;
+    refreshtimer=(FXTimer*)-1;
+    mountstimer=(FXTimer*)-1;
     expandtimer=(FXTimer*)-1;
 }
 
