@@ -4,10 +4,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <sys/wait.h>
 
-#include <fox/fx.h>
-#include <fox/fxkeys.h>
-#include <fox/FXPNGIcon.h>
+#include <fox-1.2/fx.h>
+#include <fox-1.2/fxkeys.h>
+#include <fox-1.2/FXPNGIcon.h>
 
 #include "icons.h"
 #include "DirPanel.h"
@@ -38,6 +39,7 @@
 extern FXbool confirm_del;
 extern FXString clipboard;
 extern FXuint clptype;
+extern FXMainWindow *mainWindow;
 #if defined(linux)
 extern FXStringDict* devices;
 #endif
@@ -50,8 +52,9 @@ FXDEFMAP(DirPanel) DirPanelMap[]={
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_COLLAPSETREE,DirPanel::onCollapseTree),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_PROPERTIES,DirPanel::onCmdProperties),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_ARCHIVE,DirPanel::onCmdAddToArch),
-                                   FXMAPFUNC(SEL_RIGHTBUTTONPRESS,DirPanel::ID_DIR_PANEL,DirPanel::onPopupMenu),
+                                   FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,DirPanel::ID_DIR_PANEL,DirPanel::onPopupMenu),
                                	   FXMAPFUNC(SEL_CLICKED,DirPanel::ID_DIR_PANEL,DirPanel::onCmdDirectory),
+                               	   FXMAPFUNC(SEL_EXPANDED,DirPanel::ID_DIR_PANEL,DirPanel::onExpand),
                                	   FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_COPY,DirPanel::onCmdDirMan),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_MOVE,DirPanel::onCmdDirMan),
                                    FXMAPFUNC(SEL_COMMAND,DirPanel::ID_DIR_RENAME,DirPanel::onCmdDirMan),
@@ -104,19 +107,20 @@ DirPanel::DirPanel(FXComposite *p,FXuint opts,FXint x,FXint y,FXint w,FXint h):
 	FXIcon *hidehiddenicon=new FXPNGIcon(getApp(),hidehidden);
 
 	// Construct directory panel
-    FXVerticalFrame* cont=new FXVerticalFrame(this,LAYOUT_FILL_Y|LAYOUT_FILL_X|FRAME_SUNKEN,0,0,0,0, 0,0,0,0);    
-	FXPacker* packer=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN,0,0,0,0, 0,0,0,0);
+    FXVerticalFrame* cont=new FXVerticalFrame(this,LAYOUT_FILL_Y|LAYOUT_FILL_X|FRAME_SUNKEN,0,0,0,0, 0,0,0,0, 1,1);    
+
+	FXPacker* packer=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X|FRAME_RAISED,0,0,0,0, 0,0,0,0);
+    new FXButton(packer,_("\tHide"),new FXPNGIcon(getApp(),small_x),this,FXWindow::ID_HIDE,BUTTON_TOOLBAR|LAYOUT_RIGHT|FRAME_RAISED,0,0,0,0, 3,3,0,0);  
+	new FXLabel(packer,_("Folders"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X);
 
     list=new DirList(cont,this,ID_DIR_PANEL,LAYOUT_FILL_X|LAYOUT_FILL_Y|TREELIST_BROWSESELECT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|ICONLIST_BIG_ICONS);
 
-	FXPacker* packer2=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
-    new FXToggleButton(packer2,_("\tShow hidden folders (Ctrl-F6)"),_("\tHide hidden folders (Ctrl-F6)"),showhiddenicon,hidehiddenicon,this,ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_LEFT|ICON_BEFORE_TEXT);
-    status=new FXLabel(packer2,_("Status"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
-    status->setTarget(this);
-    status->setSelector(MKUINT(DirPanel::ID_STATUS,SEL_UPDATE));
-
-    new FXButton(packer,_("\tHide"),new FXPNGIcon(getApp(),small_x),this,FXWindow::ID_HIDE,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_RIGHT,0,0,0,0, 3,3,0,0);  
-	new FXLabel(packer,_("Folders"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X);
+	statusbar=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);
+    statusbar->setTarget(this);
+    statusbar->setSelector(FXSEL(SEL_UPDATE,DirPanel::ID_STATUS));
+    new FXToggleButton(statusbar,_("\tShow hidden folders (Ctrl-F6)"),_("\tHide hidden folders (Ctrl-F6)"),showhiddenicon,hidehiddenicon,this,
+	                   ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
+    status=new FXLabel(statusbar,_("Status"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
 }
 
 
@@ -141,6 +145,7 @@ DirPanel::~DirPanel()
 	delete colltreeicon;
 	delete collfoldericon;
 	delete list;
+	delete statusbar;
 	delete status;
 }
 
@@ -148,7 +153,13 @@ DirPanel::~DirPanel()
 void DirPanel::create()
 {
 	FXVerticalFrame::create();
-	list->create();
+}
+
+// To pass the expand message to DirList
+long DirPanel::onExpand(FXObject*,FXSelector,void* ptr)
+{
+	list->handle(this,FXSEL(SEL_EXPANDED,0),(void*)ptr);
+	return 1;
 }
 
 
@@ -164,8 +175,8 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
             MessageBox::error(this,MBOX_OK,_("Error"),_(" Permission to: %s denied."), directory.text());
             return 0;
         }
-		FilePanel* currentpanel=((XFileExplorer*) getApp()->getMainWindow())->lpanel->current;
-		FXComboBox* address=((XFileExplorer*) getApp()->getMainWindow())->address;
+		FilePanel* currentpanel=((XFileExplorer*) mainWindow)->lpanel->current;
+		FXComboBox* address=((XFileExplorer*) mainWindow)->address;
         currentpanel->list->setDirectory(directory);
         
 		// Remember latest directory in the location address
@@ -181,7 +192,7 @@ long DirPanel::onCmdDirectory(FXObject*,FXSelector,void* ptr)
 		}
        	while(i < count)
 		{
-       		item = address->retrieveItem(i++);
+       		item = address->getItem(i++);
        		if(!strcmp((const char*)&p[0],(const char*)&item[0]))
 			{
 				i--;
@@ -206,24 +217,24 @@ long DirPanel::onCmdToggleHidden(FXObject*,FXSelector,void*)
 long DirPanel::onUpdToggleHidden(FXObject* sender,FXSelector,void*)
 {
     if(list->showHiddenFiles())
-        sender->handle(this,MKUINT(ID_CHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
     else
-        sender->handle(this,MKUINT(ID_UNCHECK,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
     return 1;
 }
 
 
 long DirPanel::onCmdToggleTree(FXObject* sender,FXSelector sel,void* ptr)
 {
-	return this->handle(sender,MKUINT(FXWindow::ID_TOGGLESHOWN,SEL_COMMAND),ptr);
+	return this->handle(sender,FXSEL(SEL_COMMAND,FXWindow::ID_TOGGLESHOWN),ptr);
 }
 
 long DirPanel::onUpdToggleTree(FXObject* sender,FXSelector sel,void* ptr)
 {
     if(this->shown())
-        sender->handle(this,MKUINT(FXWindow::ID_CHECK,SEL_COMMAND),ptr);
+        sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_CHECK),ptr);
     else
-        sender->handle(this,MKUINT(FXWindow::ID_UNCHECK,SEL_COMMAND),ptr);
+        sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_UNCHECK),ptr);
     return 1;
 }
 
@@ -245,50 +256,47 @@ long DirPanel::onPopupMenu(FXObject* o,FXSelector s,void* p)
 	list->setCurrentItem(item,TRUE);
 	FXString dir=list->getItemPathname((TreeItem*)item);
 	list->setDirectory(dir);
-	((XFileExplorer*) getApp()->getMainWindow())->lpanel->current->list->setDirectory(dir);
+	((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(dir);
 
     // Popup menu pane
-    static FXMenuPane *menu = NULL;
-    if(menu)
-        delete menu;
-    menu = new FXMenuPane(this);
+    FXMenuPane menu(this);
     
 	// Menu
-    new FXMenuCommand(menu,_("Terminal"),xtermicon,this,ID_XTERM);
-	new FXMenuCommand(menu,_("New folder..."),newfoldericon,this,ID_NEW_DIR);
-	new FXMenuCommand(menu,_("Add to archive..."),archicon,this,ID_ARCHIVE);
+    new FXMenuCommand(&menu,_("&Terminal"),xtermicon,this,ID_XTERM);
+	new FXMenuCommand(&menu,_("New f&older..."),newfoldericon,this,ID_NEW_DIR);
+	new FXMenuCommand(&menu,_("&Add to archive..."),archicon,this,ID_ARCHIVE);
 #if defined(linux)
 	if (isLink(dir))
 		dir=readlink(dir);
     if(devices->find(dir.text()))
 	{
-    	new FXMenuSeparator(menu);
-		new FXMenuCommand(menu,_("Mount"),mapicon,this,ID_MOUNT);
-		new FXMenuCommand(menu,_("Unmount"),unmapicon,this,ID_UMOUNT);
+    	new FXMenuSeparator(&menu);
+		new FXMenuCommand(&menu,_("&Mount"),mapicon,this,ID_MOUNT);
+		new FXMenuCommand(&menu,_("Unmount"),unmapicon,this,ID_UMOUNT);
 	}
 #endif
-    new FXMenuSeparator(menu);
-	new FXMenuCommand(menu,_("Copy"),copyicon,this,ID_COPY_CLP);
-	new FXMenuCommand(menu,_("Cut"),cuticon,this,ID_CUT_CLP);
+    new FXMenuSeparator(&menu);
+	new FXMenuCommand(&menu,_("&Copy"),copyicon,this,ID_COPY_CLP);
+	new FXMenuCommand(&menu,_("C&ut"),cuticon,this,ID_CUT_CLP);
 	if(!clipboard.empty())
-		new FXMenuCommand(menu,_("Paste"),pasteicon,this,ID_PASTE_CLP);
-    new FXMenuSeparator(menu);
-	new FXMenuCommand(menu,_("Move..."),moveicon,this,ID_DIR_MOVE);
-	new FXMenuCommand(menu,_("Rename..."),renameicon,this,ID_DIR_RENAME);
-	new FXMenuCommand(menu,_("Symlink..."),symlinkicon,this,ID_DIR_SLINK);
-	new FXMenuCommand(menu,_("Delete"),delicon,this,ID_DIR_DELETE);
-    new FXMenuSeparator(menu);
-	new FXMenuCommand(menu,_("Hidden folders"),NULL,this,ID_TOGGLE_HIDDEN);
-	new FXMenuCommand(menu,_("Expand"),expfoldericon,this,ID_EXPANDDIR);
-	new FXMenuCommand(menu,_("Collapse"),collfoldericon,this,ID_COLLAPSEDIR);
-	new FXMenuCommand(menu,_("Expand tree"),exptreeicon,this,ID_EXPANDTREE);
-	new FXMenuCommand(menu,_("Collapse tree"),colltreeicon,this,ID_COLLAPSETREE);
-    new FXMenuSeparator(menu);
-	new FXMenuCommand(menu,_("Properties"),attricon,this,ID_PROPERTIES);
+		new FXMenuCommand(&menu,_("&Paste"),pasteicon,this,ID_PASTE_CLP);
+    new FXMenuSeparator(&menu);
+	new FXMenuCommand(&menu,_("&Move..."),moveicon,this,ID_DIR_MOVE);
+	new FXMenuCommand(&menu,_("Re&name..."),renameicon,this,ID_DIR_RENAME);
+	new FXMenuCommand(&menu,_("Symlin&k..."),symlinkicon,this,ID_DIR_SLINK);
+	new FXMenuCommand(&menu,_("&Delete"),delicon,this,ID_DIR_DELETE);
+    new FXMenuSeparator(&menu);
+	new FXMenuCheck(&menu,_("&Hidden folders"),this,ID_TOGGLE_HIDDEN);
+	new FXMenuCommand(&menu,_("&Expand"),expfoldericon,this,ID_EXPANDDIR);
+	new FXMenuCommand(&menu,_("Co&llapse"),collfoldericon,this,ID_COLLAPSEDIR);
+	new FXMenuCommand(&menu,_("E&xpand tree"),exptreeicon,this,ID_EXPANDTREE);
+	new FXMenuCommand(&menu,_("Collap&se tree"),colltreeicon,this,ID_COLLAPSETREE);
+    new FXMenuSeparator(&menu);
+	new FXMenuCommand(&menu,_("Proper&ties"),attricon,this,ID_PROPERTIES);
 	
-    menu->create();
-    menu->popup(NULL,x,y);
-
+    menu.create();
+    menu.popup(NULL,x,y);
+	getApp()->runModalWhileShown(&menu);
     return 1;
 }
 
@@ -401,7 +409,7 @@ long DirPanel::onCmdProperties(FXObject* sender,FXSelector,void* ptr)
 	
 	PropertiesBox* attrdlg = new PropertiesBox(this,FXFile::name(pathname),FXFile::directory(pathname));	
    	if(attrdlg->execute())
-        list->setDirectory(FXFile::directory(pathname));
+        list->setDirectory(pathname);
     delete attrdlg;
    	return 1;
 }
@@ -415,7 +423,8 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
 	FXString name=list->getItemText(item);
 	FXString pathname=list->getItemPathname((TreeItem*)item);	
 	FXString parentdir=FXFile::directory(pathname);
-
+	FXString archive="";
+	
     static char history[ADD_TO_ARCH_HIST_SIZE][100];
     static int n=0;
     int i;
@@ -425,19 +434,22 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
     // Default archive is tar.gz 
 	FXString command="/bin/tar -zcvf ";
     
-	dialog = new HistInputDialog(this,pathname,_("Create new archive: (e.g. archive.tar.gz)"),_("Add To Archive"));
+	dialog = new HistInputDialog(this,archive,_("Create new archive: (e.g. archive.tar.gz)"),_("Add To Archive"));
     for(int i=0;i<n;i++)
         dialog->appendItem(history[i]);
     dialog->CursorEnd();
     if(dialog->execute())
     {
-        FXString archive=dialog->getText();
+        archive=parentdir+PATHSEPSTRING+dialog->getText();
 
         // Handle zip and bz2 archives
-        if (strstr(archive.text(),".zip") != NULL || strstr(archive.text(),".ZIP") != NULL)
+        FXString extension=archive.rafter('.',1);
+		if (extension=="zip" || extension=="ZIP")
             command="/usr/bin/zip -r ";
-        else if (strstr(archive.text(),".bz2") != NULL || strstr(archive.text(),".tbz2") != NULL)
+        else if (extension=="bz2" || extension=="BZ2" || extension=="tbz2" || extension=="TBZ2")
             command="/bin/tar -jcvf ";
+		else if (extension=="Z")
+			command="/bin/tar -Zcvf ";
 
 		// Archive command name
 		command+=archive+" "+"\""+name+"\"";
@@ -478,7 +490,7 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector sel,void* ptr)
 
 		// Display parent directory in DirList and FileList
 		list->setDirectory(parentdir);
-		((XFileExplorer*) getApp()->getMainWindow())->lpanel->current->list->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
     }
     delete dialog;
     return 1;
@@ -497,22 +509,22 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void*)
     FXString target = FXFile::directory(source);
 	FXString param = target+"\n"+"-1"+"\n"+source;
 
-    switch(SELID(sel))
+    switch(FXSELID(sel))
     {
     case ID_DIR_COPY:
-        sel = MKUINT(XFileExplorer::ID_FILE_COPY,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_COPY);
         break;
     case ID_DIR_MOVE:
-        sel = MKUINT(XFileExplorer::ID_FILE_MOVE,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_MOVE);
         break;
     case ID_DIR_RENAME:
-        sel = MKUINT(XFileExplorer::ID_FILE_RENAME,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_RENAME);
         break;
     case ID_DIR_SLINK:
-        sel = MKUINT(XFileExplorer::ID_FILE_SLINK,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_SLINK);
         break;
     }
-    getApp()->getMainWindow()->handle(this,sel,strdup(param.text()));
+    mainWindow->handle(this,sel,strdup(param.text()));
 
 	// Force dirpanel refresh
     list->onRefresh(0,0,0);
@@ -539,8 +551,8 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
     {
         FXPNGIcon icon(getApp(),delete_big);
 		FXString message=_("Delete folder ") + pathname + " ?";
-		MessageBox box(this,_("Confirm Delete"),message,&icon,MBOX_YES_NO|DECOR_TITLE|DECOR_BORDER);
-        if(box.execute() != MBOX_CLICKED_YES)
+		MessageBox box(this,_("Confirm Delete"),message,&icon,MBOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+        if(box.execute() != MBOX_CLICKED_OK)
             return 0;
     }
 
@@ -553,9 +565,9 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
     {
 		// Get process uid and directory uid
 		FXuint uid=getuid();
-		struct stat status;
-		lstat(pathname.text(),&status);
-		FXuint diruid=status.st_uid;
+		struct stat buf;
+		lstatout(pathname.text(),&buf);
+		FXuint diruid=buf.st_uid;
 
 		// If we are owner of the directory
 		if (diruid==uid)
@@ -565,9 +577,9 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
 			f->hide();
 			FXPNGIcon icon(getApp(),errorIcon);
 			FXString str=_("Folder ") + pathname + _(" is write-protected, delete it anyway?");
-        	MessageBox box(this,_("Confirm Delete"),str,&icon,MBOX_YES_NO|DECOR_TITLE|DECOR_BORDER);        	
+        	MessageBox box(this,_("Confirm Delete"),str,&icon,MBOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
 			FXuint answer=box.execute();
-			if(answer == MBOX_CLICKED_YES)
+			if(answer == MBOX_CLICKED_OK)
 			{
 				f->remove(pathname); 	
 
@@ -577,7 +589,7 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
 				
 				// Return to parent directory in DirList and FileList
 				list->setDirectory(parentdir);
-				((XFileExplorer*) getApp()->getMainWindow())->lpanel->current->list->setDirectory(parentdir);
+				((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
 			}
 		}
 					
@@ -603,14 +615,14 @@ long DirPanel::onCmdDirDel(FXObject*,FXSelector,void*)
 		}
 		// Return to parent directory in DirList and FileList
 		list->setDirectory(parentdir);
-		((XFileExplorer*) getApp()->getMainWindow())->lpanel->current->list->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->lpanel->current->list->setDirectory(parentdir);
 	}
 
 	delete f;
 
 	// Force DirPanel and FilePanel refresh
     list->onRefresh(0,0,0);
-	((XFileExplorer*) getApp()->getMainWindow())->lpanel->onRefresh(0,0,0);
+	((XFileExplorer*) mainWindow)->lpanel->onRefresh(0,0,0);
     return 1;
 }
 
@@ -621,43 +633,26 @@ long DirPanel::onCmdNewDir(FXObject*,FXSelector,void*)
 	// Current item
     DirItem* item=(DirItem*)list->getCurrentItem();
 
-	FXString buf=list->getItemPathname((TreeItem*)item);
-	FXString oldbuf=buf;
-    FXString cmd = "mkdir ";
+    FXString dirname="";	
+	FXString dirpath=list->getItemPathname((TreeItem*)item);
+    if(dirpath!=ROOTDIR)
+        dirpath+=PATHSEPSTRING;
     
-    InputDialog* dialog = new InputDialog(this,buf,_("Create new folder..."),_("New Folder"));
+    InputDialog* dialog = new InputDialog(this,dirname,_("Create new folder..."),_("New Folder"));
     dialog->CursorEnd();
     if(dialog->execute())
     {
-        buf=dialog->getText();
-		
-		// Test some error conditions
-		if (exists(dequote(buf)))
+		dirname=dirpath+dialog->getText();		
+        if(dirname!=dirpath)
         {
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Folder %s already exists"), buf.text());
-        	return 0;
-		}
-		FXString parentdir;
-		if (FXFile::name(buf)=="")
-			parentdir=FXFile::directory(FXFile::directory(buf));
-		else			
-			parentdir=FXFile::directory(buf);
-		if (!exists(dequote(parentdir)))
-        {
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Folder %s doesn't exist"), parentdir.text());
-        	return 0;
-		}
-		if (!FXFile::isWritable(parentdir))
-		{
-         	MessageBox::error(this,MBOX_OK,_("Error"),_("Can't write to %s : Permission denied"), parentdir.text());
-        	return 0;
-		}
-        if(oldbuf!=buf)
-        {
-            cmd+=buf;
-            cmd+=" &";
-            system(cmd.text());
-        }
+			// Create the new dir
+			FXint ret=mkdir(dirname.text(),0755);
+			if (ret==-1)
+			{
+         		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
+    			return 0;
+			}
+		}							
     }
     delete dialog;
 	
@@ -688,19 +683,19 @@ long DirPanel::onCmdPaste(FXObject*,FXSelector sel,void*)
     FXString param;
     FXString targetdir;
 
-	targetdir=((XFileExplorer*) getApp()->getMainWindow())->lpanel->current->list->getDirectory();
+	targetdir=((XFileExplorer*) mainWindow)->lpanel->current->list->getDirectory();
     param = targetdir+"\n"+clipboard;
 
     switch(clptype)
     {
     case COPY_CLP:
-        sel = MKUINT(XFileExplorer::ID_FILE_COPY,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_COPY);
         break;
     case CUT_CLP:
-        sel = MKUINT(XFileExplorer::ID_FILE_CUT,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_CUT);
         break;
     }
-    getApp()->getMainWindow()->handle(this,sel,strdup(param.text()));
+    mainWindow->handle(this,sel,strdup(param.text()));
     clipboard = "";
 
 	// Force dirpanel refresh
@@ -719,7 +714,7 @@ long DirPanel::onCmdClp(FXObject*,FXSelector sel,void*)
 
 	// Clipboard type
     clipboard = "";
-	if (SELID(sel)==ID_CUT_CLP)
+	if (FXSELID(sel)==ID_CUT_CLP)
 		clptype=CUT_CLP;
 	else
 		clptype=COPY_CLP;
@@ -748,10 +743,10 @@ long DirPanel::onCmdMount(FXObject*,FXSelector sel,void*)
 		dir=FXFile::symlink(dir);
 
     // Select the command and set the appropriate message
-    if(SELID(sel)==ID_MOUNT)
+    if(FXSELID(sel)==ID_MOUNT)
     {
         op=MOUNT;
-		msg="Mount";
+		msg=_("Mount");
         cmd="/bin/mount ";
     }
     else
@@ -805,26 +800,30 @@ long DirPanel::onUpdPaste(FXObject* o,FXSelector,void*)
     if(style & BUTTON_TOOLBAR)
     {
         if(!clipboard.empty())
-            o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+            o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
         else
-            o->handle(this,MKUINT(FXWindow::ID_DISABLE,SEL_COMMAND),NULL);
+            o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
     }
     else
-        o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+        o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
 
     return 1;
 }
 
+
 // Update the status bar and the directory path name
 long DirPanel::onUpdStatus(FXObject* sender,FXSelector,void*)
 {
+	unsigned long long dsize;
+	char buf[MAXPATHLEN+1], size[64], hsize[64];
+	
 	// Name of the current selected item
 	TreeItem* item=(TreeItem*)list->getCurrentItem();
 	
 	// There is no selected item
 	if (item==NULL)
 	{
-		status->setText("Total");
+		status->setText("--");
 		return 0;
 	}
 	
@@ -834,36 +833,27 @@ long DirPanel::onUpdStatus(FXObject* sender,FXSelector,void*)
 	// File doesn't exist
 	if (!exists(dequote(path)))
 	{
-		status->setText("Total");
+		status->setText("--");
 		return 0;
 	}
 
-	// Update the path name
+	// Size of the files present in the directory
 	path=quote(path,FALSE);
-	//chdir(path.text());
-
-	// Size of the files in this directory (not recursive!)
-	FILE *p;
-	char buf[MAXPATHLEN+1];
-	char size[64], hsize[64];
-	sprintf(buf,"ls -sk %s 2> /dev/null",path.text());
-	p=popen(buf,"r");
-	if(!p)
-	{
-		MessageBox::error(this,MBOX_OK,_("Error"),_("Failed command : %s"),buf);
-		return -1;
-	}
-	fgets(buf,sizeof(buf),p);
-	strcpy(size,strtok(buf,"total\n"));
-	pclose(p);
+	strcpy(buf,path.text());
+	dsize=dirsize(buf);
 
 	// Size in human readable form
-	sprintf(size,"%lu",atol(size)*1024);
-	::Size(size,hsize);
+	sprintf(size,"%llu",dsize);
+	::hSize(size,hsize);
 
 	// Update the status label
-	sprintf(buf,_("Total %s"),hsize);
+	sprintf(buf,_("%s"),hsize);
 	status->setText(buf);
 
+	// Update the path in the window title
+	if(getuid()==0)
+		mainWindow->setTitle("Xfe (root) - " + path);
+	else
+		mainWindow->setTitle("Xfe - " + path);
     return 1;
 }
