@@ -5,6 +5,7 @@
 #include "config.h"
 #include "i18n.h"
 
+#include <signal.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/time.h>
@@ -14,9 +15,11 @@
 #include <grp.h>
 #include <ctype.h>
 #include <unistd.h>
+#include <sys/wait.h>
+#include <time.h>
 
-#include <fox/fx.h>
-#include <fox/fxkeys.h>
+#include <fox-1.2/fx.h>
+#include <fox-1.2/fxkeys.h>
 
 #include "icons.h"
 #include "File.h"
@@ -24,6 +27,11 @@
 #include "MessageBox.h"
 #include "CommandWindow.h"
 
+#if defined(linux)
+extern FXStringDict* devices;
+extern FXStringDict* mounts;
+#endif
+
 
 // Maximum length of a file name
 #ifndef MAXPATHLEN
@@ -36,19 +44,324 @@
 // Progress dialog width
 #define PDIALOG_WIDTH 150
 
+// Global variables
+extern FXMainWindow *mainWindow;
 extern FXbool confirm_overwrite;
 
+// Timeout for stat functions (seconds)
+#define TIMEOUT 5
+
+// Replacement of the stat function with a timeout
+int statout(const char *filename, struct stat *buf)
+{
+#if defined(linux)
+	// It's a mount point
+	if(mounts->find(filename))
+	{
+		// Mount point is NFS or SMB
+		if(!strcmp(mounts->find(filename),"nfs") || !strcmp(mounts->find(filename),"smbfs"))
+		{
+			int pid, ret;
+			time_t t0, t;
+	
+			// Create child process
+			pid = fork();
+    		if (pid == -1)
+        		return -1;
+    
+			if (pid == 0)
+    		{
+        		// Here, we are running as the child process!
+				ret=stat(filename,buf);
+				exit(ret);
+    		}
+    		else
+    		{
+        		// Here, we are running as the parent process!
+    			time(&t0);
+				while (1)
+				{
+					if ( (waitpid(pid,&ret,WNOHANG)==0 ) )
+					{
+						// Child is still running, wait
+						time(&t);
+				
+						// Timeout exceeded, abort
+						if (difftime(t,t0)>TIMEOUT)
+						{
+							kill(pid,SIGKILL);
+							return -1;
+						}
+					}
+					else
+					{
+						// Child has finished
+						if (ret==0)
+						{	
+							ret=stat(filename,buf);
+							return ret;
+						}
+						else
+							return -1;
+					}
+				}
+			}
+		}
+		// Mount point is down
+		else if(!strcmp(mounts->find(filename),"down"))
+			return -1;
+		
+		// Other mount point
+		else
+			return stat(filename,buf);		
+	}
+		
+	// It's not a mount point
+	else
+#endif
+	return stat(filename,buf);
+}
+
+// Replacement of the lstat function with a timeout
+int lstatout(const char *filename, struct stat *buf)
+{
+#if defined(linux)
+	// It's a mount point and it's up 
+	if(mounts->find(filename))
+	{
+		// Mount point is NFS or SMB
+		if(!strcmp(mounts->find(filename),"nfs") || !strcmp(mounts->find(filename),"smbfs"))
+		{
+			int pid, ret;
+			time_t t0, t;
+	
+			// Create child process
+			pid = fork();
+    		if (pid == -1)
+       			return -1;
+    
+			if (pid == 0)
+    		{
+        		// Here, we are running as the child process!
+				ret=lstat(filename,buf);
+				exit(ret);
+    		}
+    		else
+    		{
+        		// Here, we are running as the parent process!
+				time(&t0);
+				while (1)
+				{
+					if ( (waitpid(pid,&ret,WNOHANG)==0 ) )
+					{
+						// Child is still running, wait
+						time(&t);
+				
+						// Timeout exceeded, abort
+						if (difftime(t,t0)>TIMEOUT)
+						{
+							kill(pid,SIGKILL);
+							return -1;
+						}
+					}
+					else
+					{
+						// Child has finished
+						if (ret==0)
+						{	
+							ret=lstat(filename,buf);
+							return ret;
+						}
+						else
+							return -1;
+					}
+				}
+			}
+		}
+		// Mount point is down
+		else if(!strcmp(mounts->find(filename),"down"))
+			return -1;
+		
+		// Other mount point
+		else
+			return lstat(filename,buf);		
+	}
+		
+	// It's not a mount point
+	else
+#endif
+	return lstat(filename,buf);
+}
+
+
+#if defined(linux)
+// Stat function used to test if a mount point is up or down
+int mtlstat(const char *filename, struct stat *buf)
+{
+	int pid, ret;
+	time_t t0, t;
+	
+	// Create child process
+	pid = fork();
+    if (pid == -1)
+       	return -1;
+    
+	if (pid == 0)
+    {
+        // Here, we are running as the child process!
+		ret=lstat(filename,buf);
+		exit(ret);
+    }
+    else
+    {
+        // Here, we are running as the parent process!
+		time(&t0);
+		while (1)
+		{
+			if ( (waitpid(pid,&ret,WNOHANG)==0 ) )
+			{
+				// Child is still running, wait
+				time(&t);
+				
+				// Timeout exceeded, abort
+				if (difftime(t,t0)>TIMEOUT)
+				{
+					kill(pid,SIGKILL);
+					return -1;
+				}
+			}
+			else
+			{
+				// Child has finished
+				if (ret==0)
+				{	
+					ret=lstat(filename,buf);
+					return ret;
+				}
+				else
+					return -1;
+			}
+		}
+	}
+}
+#endif
+
+
+// Obtain the non recursive size of a directory
+unsigned long long dirsize(char *path)
+{
+    DIR *dp;
+	struct dirent *dirp;
+	struct stat statbuf;
+	char buf[MAXPATHLEN];
+	unsigned long long dsize=0;
+	int l;
+			
+	if((dp=opendir(path))==NULL)
+        return 0;
+	
+	l=strlen(path);
+	if (l>0 && path[l-1]=='/')
+		path[l-1]='\0';
+
+	while((dirp=readdir(dp)))
+    {
+        if ( !strcmp(dirp->d_name, ".")||!strcmp(dirp->d_name, "..") )
+            continue;
+		
+		sprintf(buf,"%s/%s",path,dirp->d_name);
+		
+#if defined(linux)
+		if (!mounts->find(buf))
+		{
+#endif
+ 			if(lstat(buf,&statbuf)<0)
+        		fprintf(stderr,"Dirsize : cannot stat %s\n", buf);
+			else
+			{
+				if(!S_ISDIR(statbuf.st_mode))
+		  			dsize += (unsigned long long) statbuf.st_size;
+			}
+#if defined(linux)
+		}
+#endif
+	}
+	if(closedir(dp)<0)
+        fprintf(stderr,"Cannot close directory %s\n", path);
+	return dsize;
+}
+
+// Obtain the recursive size of a directory
+unsigned long long dirpath( char *path)
+{
+	struct stat statbuf;
+	struct dirent *dirp;
+    char *ptr;
+    DIR *dp;
+	unsigned long long dsize;
+	int ret;
+
+#if defined(linux)
+    if(mounts->find(path))
+		ret=lstatout(path,&statbuf);
+	else
+#endif
+		ret=lstat(path,&statbuf);
+	if(ret<0)
+    {
+        fprintf(stderr,"Dirpath : cannot stat %s\n", path);
+        return 0;
+    }
+    dsize = (unsigned long long) statbuf.st_size;
+    
+	// Not a directory
+	if(!S_ISDIR(statbuf.st_mode))
+        return dsize;
+    
+	ptr=path + strlen(path);
+    if(ptr[-1]!='/')
+    {
+        *ptr++='/';
+        *ptr='\0';
+    }
+    
+	if((dp=opendir(path))==NULL)
+        return 0;
+    
+	while((dirp=readdir(dp)))
+    {
+        if( !strcmp(dirp->d_name, ".")||!strcmp(dirp->d_name, "..") )
+            continue;
+        strcpy(ptr, dirp->d_name);
+		
+		// Recursive call
+        dsize+=dirpath(path);
+    }
+	
+    ptr[-1]='\0'; // ??
+	
+    if(closedir(dp)<0)
+        fprintf(stderr,"Cannot close directory %s\n", path);
+    return dsize;
+}
+
 // Write the file size in human readable form (bytes or Kbytes or Mbytes)
-void Size(FXchar* size,FXchar *hsize)
+void hSize(FXchar* size,FXchar *hsize)
 {
     int flag=0;
     FXchar suf[50];
-	
-    unsigned long lsize = atol(size);
+
+    unsigned long long lsize = strtoull(size,NULL,10);
     float fsize=0.0;
 
 	strcpy(suf,_("bytes")); 
-	if(lsize>1000000)
+	if(lsize>1000000000)
+    {
+        fsize=lsize/1073741824.0;
+        strcpy(suf,_("GB"));
+        flag=1;
+    }
+	else if(lsize>1000000)
     {
         fsize=lsize/1048576.0;
         strcpy(suf,_("MB"));
@@ -68,7 +381,7 @@ void Size(FXchar* size,FXchar *hsize)
             sprintf(hsize,"%.1f %s",fsize,suf);
     }
     else
-        sprintf(hsize,"%lu %s",lsize,suf);
+        sprintf(hsize,"%llu %s",lsize,suf);
 }
 
 
@@ -224,41 +537,41 @@ FXint isEmptyDir(const FXString directory)
 FXbool exists(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (stat(file.text(),&status)==0);
+  	return !file.empty() && (statout(file.text(),&status)==0);
 }
 
 // Check if file represents a directory
 FXbool isDirectory(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (stat(file.text(),&status)==0) && S_ISDIR(status.st_mode);
+  	return !file.empty() && (statout(file.text(),&status)==0) && S_ISDIR(status.st_mode);
 }
 
 // Check if file represents a file
 FXbool isFile(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (stat(file.text(),&status)==0) && S_ISREG(status.st_mode);
+  	return !file.empty() && (statout(file.text(),&status)==0) && S_ISREG(status.st_mode);
 }
 
 // Check if file represents a link
 FXbool isLink(const FXString& file)
 {
   	struct stat status;
-  	return !file.empty() && (lstat(file.text(),&status)==0) && S_ISLNK(status.st_mode);
+  	return !file.empty() && (lstatout(file.text(),&status)==0) && S_ISLNK(status.st_mode);
 }
 
 // Get file info
 FXbool info(const FXString& file,struct stat& inf)
 {
-  	return !file.empty() && (stat(file.text(),&inf)==0);
+  	return !file.empty() && (statout(file.text(),&inf)==0);
 }
 
 // Read symbolic link
 FXString readlink(const FXString& file)
 {
 	FXchar lnk[MAXPATHLEN+1];
-	FXint len=::readlink(file.text(),lnk,MAXPATHLEN);
+	FXint len=readlink(file.text(),lnk,MAXPATHLEN);
 	if(0<=len)
   		return FXString(lnk,len);
   	else
@@ -267,15 +580,6 @@ FXString readlink(const FXString& file)
 
 
 
-// Timer record (redefined here to use it in checkTimeout)
-struct FXTimer
-{
-	FXTimer       *next;              // Next timeout in list
-	FXObject      *target;            // Receiver object
-	FXSelector     message;           // Message sent to receiver
-	struct timeval due;               // When timer is due
-};
-
 // Message Map
 FXDEFMAP(File) FileMap[]={
                              FXMAPFUNC(SEL_COMMAND,File::ID_CANCEL_BUTTON,File::onCmdCancel),
@@ -316,7 +620,7 @@ File::File(FXApp* a, FXString title, const unsigned int operation):FXDialogBox(a
 			pbar=new FXProgressBar(contents,NULL,0,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|PROGRESSBAR_PERCENTAGE,0,0,0,0,PDIALOG_WIDTH);
 		
 			// Timer on
-			timer=getApp()->addTimeout(SHOW_PBAR_DELAY,this,File::ID_TIMEOUT);
+			timer=getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
 			break;
 
     	case MOVE:
@@ -325,7 +629,7 @@ File::File(FXApp* a, FXString title, const unsigned int operation):FXDialogBox(a
     		downlabel=new FXLabel(contents,_("Target :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
 		
 			// Timer on
-			timer=getApp()->addTimeout(SHOW_PBAR_DELAY,this,File::ID_TIMEOUT);
+			timer=getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
 			break;
 
     	case DELETE:
@@ -334,7 +638,7 @@ File::File(FXApp* a, FXString title, const unsigned int operation):FXDialogBox(a
     		downlabel=new FXLabel(contents,_("From :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
 
 			// Timer on
-			timer=getApp()->addTimeout(SHOW_PBAR_DELAY,this,File::ID_TIMEOUT);
+			timer=getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
 			break;
 
     	case CHMOD:
@@ -343,7 +647,7 @@ File::File(FXApp* a, FXString title, const unsigned int operation):FXDialogBox(a
     		downlabel=new FXLabel(contents,_("File :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
 
 			// Timer on
-			timer=getApp()->addTimeout(SHOW_PBAR_DELAY,this,File::ID_TIMEOUT);
+			timer=getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
 			break;
 
     	case CHOWN:
@@ -352,7 +656,7 @@ File::File(FXApp* a, FXString title, const unsigned int operation):FXDialogBox(a
     		downlabel=new FXLabel(contents,_("File :"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_X);
 
 			// Timer on
-			timer=getApp()->addTimeout(SHOW_PBAR_DELAY,this,File::ID_TIMEOUT);
+			timer=getApp()->addTimeout(this,File::ID_TIMEOUT,SHOW_PBAR_DELAY);
 			break;
 
 #if defined(linux)
@@ -410,20 +714,19 @@ void File::create()
 // Force check of timeout for progress dialog (to avoid latency problems)
 int File::checkTimeout(FXTimer *timer)
 {
-	timeval now;
-	
+	timeval now;	
 	if (timer)
 	{
-		gettimeofday(&now,NULL);
-		if(now.tv_sec>timer->due.tv_sec || (now.tv_sec==timer->due.tv_sec && now.tv_usec>=timer->due.tv_usec))
-		{
-			getApp()->removeTimeout(timer);
-			if (allowPdialog)
-				show(PLACEMENT_OWNER);
-			getApp()->forceRefresh();
-			getApp()->flush();
-			return 1;
-		}
+		if (getApp()->remainingTimeout(timer)==0)
+			if (now.tv_sec>0)
+			{
+				getApp()->removeTimeout(timer);
+				if (allowPdialog)
+					show(PLACEMENT_OWNER);
+				getApp()->forceRefresh();
+				getApp()->flush();
+				return 1;
+			}
 	}
 	return 0;
 }
@@ -479,9 +782,9 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
     int src,dst;
     FXbool ok=FALSE;
 
-    if((src=open(source.text(),O_RDONLY))>=0)
+    if((src=::open(source.text(),O_RDONLY))>=0)
     {
-        if(stat(source.text(),&status)==0)
+        if(statout(source.text(),&status)==0)
         {
 			// If destination is a directory
 			if(isDirectory(target))
@@ -491,7 +794,7 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
 				
          	// Copy file block by block
 			size=status.st_size; 
-			if((dst=open(destfile.text(),O_WRONLY|O_CREAT|O_TRUNC,status.st_mode))>=0)
+			if((dst=::open(destfile.text(),O_WRONLY|O_CREAT|O_TRUNC,status.st_mode))>=0)
             {
                 while(1)
                 {
@@ -516,7 +819,7 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
 
 					// Give cancel button an opportunity to be clicked
 					if(cancelButton)
-						getApp()->runWhileEvents(cancelButton);
+						getApp()->runModalWhileEvents(cancelButton);
 
 					// Set labels for progress dialog
 					FXString label=_("Source : ")+source;
@@ -528,8 +831,8 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
 					// If cancel button was clicked, close files and return
 					if (isCancelled)
 					{
-						close(dst);
-						close(src);
+						::close(dst);
+						::close(src);
 						return FALSE;
 					}
                     nwritten=File::fullwrite(dst,buffer,nread);
@@ -541,10 +844,10 @@ FXbool File::copyfile(const FXString& source, const FXString& target)
                 }
                 ok=TRUE;
 err:
-                close(dst);
+                ::close(dst);
             }
         }
-        close(src);
+        ::close(src);
     }
     return ok;
 }
@@ -577,7 +880,7 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
         return FALSE;
 
     // Can we stat it
-    if(lstat(destfile.text(),&status)!=0 || !S_ISDIR(status.st_mode))
+    if(lstatout(destfile.text(),&status)!=0 || !S_ISDIR(status.st_mode))
         return FALSE;
 
     // Try open directory to copy
@@ -624,17 +927,17 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
     struct stat status1,status2;
 
     // Old file or directory does not exist
-    if(lstat(source.text(),&status1)!=0)
+    if(lstatout(source.text(),&status1)!=0)
         return FALSE;
 
     // If target is not a directory, remove it if allowed
-    if(lstat(target.text(),&status2)==0)
+    if(lstatout(target.text(),&status2)==0)
     {
         if(!S_ISDIR(status2.st_mode))
         {
             if(!(overwrite|overwrite_all))
                 return FALSE;
-            if(::unlink(target.text())!=0)
+            if(unlink(target.text())!=0)
                 return FALSE;
         }
     }
@@ -649,11 +952,11 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
 
     // Source is fifo: make a new one
     if(S_ISFIFO(status1.st_mode))
-        return ::mkfifo(target.text(),status1.st_mode);
+        return mkfifo(target.text(),status1.st_mode);
 
     // Source is device: make a new one
     if(S_ISBLK(status1.st_mode) || S_ISCHR(status1.st_mode) || S_ISSOCK(status1.st_mode))
-        return ::mknod(target.text(),status1.st_mode,status1.st_rdev)==0;
+        return mknod(target.text(),status1.st_mode,status1.st_rdev)==0;
 
     // Source is symbolic link: make a new one
     if(S_ISLNK(status1.st_mode))
@@ -747,12 +1050,12 @@ FXbool File::remove(const FXString& file)
     struct stat status;
 	static FXbool ISDIR=FALSE;
 
-    if(lstat(file.text(),&status)==0)
+    if(lstatout(file.text(),&status)==0)
     {
         // It is a directory
 		if(S_ISDIR(status.st_mode))
         {
-            DIR *dirp=::opendir(file.text());
+            DIR *dirp=opendir(file.text());
             if(dirp)
             {			
                 struct dirent *dp;
@@ -767,7 +1070,7 @@ FXbool File::remove(const FXString& file)
 
 				// Give cancel button an opportunity to be clicked
 				if(cancelButton)
-					getApp()->runWhileEvents(cancelButton);
+					getApp()->runModalWhileEvents(cancelButton);
 
 				// Set labels for progress dialog
 				FXString label=_("Delete folder :")+file;
@@ -781,7 +1084,7 @@ FXbool File::remove(const FXString& file)
 				if (isCancelled)
 					return FALSE;
 
-                while((dp=::readdir(dirp))!=NULL)
+                while((dp=readdir(dirp))!=NULL)
                 {
 					if(dp->d_name[0]!='.' || (dp->d_name[1]!='\0' && (dp->d_name[1]!='.' || dp->d_name[2]!='\0')))
                     {
@@ -790,15 +1093,21 @@ FXbool File::remove(const FXString& file)
                             child.append(PATHSEP);
                         child.append(dp->d_name);
                         if(!File::remove(child))
-                            {
-                                ::closedir(dirp);
-                                return FALSE;
-                            }
+						{
+							closedir(dirp);
+							return FALSE;
+						}
                     }
                 }
-                ::closedir(dirp);
+                closedir(dirp);
             }
-            return (::rmdir(file.text())==0);
+			if (rmdir(file.text())==-1)
+			{
+				MessageBox::error(this,MBOX_OK,_("Error"),_("Cannot delete directory %s"), file.text());			
+				return FALSE;
+			}
+			else
+				return TRUE;
         }
         else
         {
@@ -811,7 +1120,7 @@ FXbool File::remove(const FXString& file)
 
 				// Give cancel button an opportunity to be clicked
 				if(cancelButton)
-					getApp()->runWhileEvents(cancelButton);
+					getApp()->runModalWhileEvents(cancelButton);
 
 				// Set labels for progress dialog
 				FXString label=_("Delete : ")+file;
@@ -825,7 +1134,13 @@ FXbool File::remove(const FXString& file)
 				if (isCancelled)
 					return FALSE;
 			}
-            return (::unlink(file.text())==0);
+			if (unlink(file.text())==-1)
+			{
+				MessageBox::error(this,MBOX_OK,_("Error"),_("Cannot delete file %s"), file.text());			
+				return FALSE;
+			}
+			else
+				return TRUE;
         }
     }
     return FALSE;
@@ -1062,7 +1377,7 @@ int File::chmod(char *path, char *file, mode_t mode, FXbool rec, FXbool dironly)
 	// Initialise the file variable with the initial path
 	strcpy(file, path);
 
-    if (lstat(path, &stats)) //if it doesn't exist
+    if (lstatout(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1076,7 +1391,7 @@ int File::chmod(char *path, char *file, mode_t mode, FXbool rec, FXbool dironly)
 
 		// Give cancel button an opportunity to be clicked
 		if(cancelButton)
-			getApp()->runWhileEvents(cancelButton);
+			getApp()->runModalWhileEvents(cancelButton);
 
 		// Set labels for progress dialog
 		FXString label=_("Changing permissions...");
@@ -1101,7 +1416,7 @@ int File::chmod(char *path, char *file, mode_t mode, FXbool rec, FXbool dironly)
 
 			// Give cancel button an opportunity to be clicked
 			if(cancelButton)
-				getApp()->runWhileEvents(cancelButton);
+				getApp()->runModalWhileEvents(cancelButton);
 
 			// Set labels for progress dialog
 			FXString label=_("Changing permissions...");
@@ -1133,7 +1448,7 @@ int File::rchmod(char *path, char *file, mode_t mode, FXbool dironly)
 	// Initialise the file variable with the initial path
 	strcpy(file, path);
 
-    if (lstat(path, &stats)) //if it doesn't exist
+    if (lstatout(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1147,7 +1462,7 @@ int File::rchmod(char *path, char *file, mode_t mode, FXbool dironly)
 
 		// Give cancel button an opportunity to be clicked
 		if(cancelButton)
-			getApp()->runWhileEvents(cancelButton);
+			getApp()->runModalWhileEvents(cancelButton);
 
 		// Set labels for progress dialog
 		FXString label=_("Changing permissions...");
@@ -1209,7 +1524,7 @@ int File::chown(char *path, char *file, uid_t uid, gid_t gid, FXbool rec, FXbool
 	// Initialise the file variable with the initial path
 	strcpy(file, path);
 
-    if (lstat(path, &stats)) //if it doesn't exist
+    if (lstatout(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1223,7 +1538,7 @@ int File::chown(char *path, char *file, uid_t uid, gid_t gid, FXbool rec, FXbool
 
 		// Give cancel button an opportunity to be clicked
 		if(cancelButton)
-			getApp()->runWhileEvents(cancelButton);
+			getApp()->runModalWhileEvents(cancelButton);
 
 		// Set labels for progress dialog
 		FXString label=_("Changing owner...");
@@ -1249,7 +1564,7 @@ int File::chown(char *path, char *file, uid_t uid, gid_t gid, FXbool rec, FXbool
 
 			// Give cancel button an opportunity to be clicked
 			if(cancelButton)
-				getApp()->runWhileEvents(cancelButton);
+				getApp()->runModalWhileEvents(cancelButton);
 
 			// Set labels for progress dialog
 			FXString label=_("Changing owner...");
@@ -1282,7 +1597,7 @@ int File::rchown(char *path, char *file, uid_t uid, gid_t gid, FXbool dironly)
 	// Initialise the file variable with the initial path
 	strcpy(file, path);
 
-    if (lstat(path, &stats)) //if it doesn't exist
+    if (lstatout(path, &stats)) //if it doesn't exist
         return -1;
 
     if (!S_ISDIR(stats.st_mode)) // file
@@ -1296,7 +1611,7 @@ int File::rchown(char *path, char *file, uid_t uid, gid_t gid, FXbool dironly)
 
 		// Give cancel button an opportunity to be clicked
 		if(cancelButton)
-			getApp()->runWhileEvents(cancelButton);
+			getApp()->runModalWhileEvents(cancelButton);
 
 		// Set labels for progress dialog
 		FXString label=_("Changing owner...");
@@ -1372,7 +1687,7 @@ int File::archive(FXString name, FXString cmd)
 		if (!overwrite_all & !skip_all)
 		{
 			FXString msg=_("File ")+name+_(" already exists. Overwrite?");
-       		ConfirmOverWriteBox* dlg = new ConfirmOverWriteBox(getApp()->getMainWindow(),_("Confirm Overwrite"),msg);
+       		ConfirmOverWriteBox* dlg = new ConfirmOverWriteBox(mainWindow,_("Confirm Overwrite"),msg);
        		FXuint answer=dlg->execute();
 			delete dlg;
        		switch(answer)
@@ -1420,7 +1735,7 @@ int File::mount(FXString dir, FXString msg, FXString cmd, unsigned int op)
 
 	// Give cancel button an opportunity to be clicked
 	if(cancelButton)
-		getApp()->runWhileEvents(cancelButton);
+		getApp()->runModalWhileEvents(cancelButton);
 
 	// If cancel button was clicked, return
 	if (isCancelled)
