@@ -2,9 +2,9 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox/fx.h>
-#include <fox/fxkeys.h>
-#include <fox/FXPNGIcon.h>
+#include <fox-1.2/fx.h>
+#include <fox-1.2/fxkeys.h>
+#include <fox-1.2/FXPNGIcon.h>
 
 #include "File.h"
 #include "FileList.h"
@@ -52,7 +52,11 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     accept=new FXButton(buttons,NULL,NULL,NULL,0,LAYOUT_FIX_X|LAYOUT_FIX_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT,0,0,0,0, 0,0,0,0);
     new FXLabel(fields,_("File F&ilter:"),NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y);
     FXHorizontalFrame *filterframe=new FXHorizontalFrame(fields,LAYOUT_FILL_COLUMN|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
-    filefilter=new FXComboBox(filterframe,10,4,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
+
+  	filefilter=new FXComboBox(filterframe,10,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
+  	filefilter->setNumVisible(4);
+
+
     readonly=new FXCheckButton(filterframe,_("Read Only"),NULL,0,ICON_BEFORE_TEXT|JUSTIFY_LEFT|LAYOUT_CENTER_Y);
     cancel=new FXButton(fields,_("&Cancel"),NULL,NULL,0,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X,0,0,0,0,20,20);
     FXHorizontalFrame *frame=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_SUNKEN|FRAME_THICK,0,0,0,0,0,0,0,0);
@@ -66,7 +70,8 @@ FileSelector::FileSelector(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint op
     workicon=new FXPNGIcon(getApp(),work);
     shownicon=new FXPNGIcon(getApp(),hidehidden);
     hiddenicon=new FXPNGIcon(getApp(),showhidden);
-    dirbox=new DirBox(buttons,5,this,ID_DIRTREE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,160,0);
+    dirbox=new DirBox(buttons,this,ID_DIRTREE,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,160,0);
+	dirbox->setNumVisible(5);
     new FXFrame(buttons,LAYOUT_FIX_WIDTH,0,0,4,1);
     new FXButton(buttons,_("\tGo up one folder\tMove up to higher folder."),updiricon,this,ID_DIRECTORY_UP,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
     new FXButton(buttons,_("\tGo to home folder\tBack to home folder."),homeicon,this,ID_HOME,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 3,3,3,3);
@@ -106,7 +111,7 @@ long FileSelector::onCmdItemDblClicked(FXObject*,FXSelector,void* ptr)
             FXObject *tgt=accept->getTarget();
             FXSelector sel=accept->getSelector();
             if(tgt)
-                tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+                tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
         }
     }
     return 1;
@@ -219,7 +224,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
             if(selectmode==SELECTFILE_DIRECTORY || selectmode==SELECTFILE_MULTIPLE_ALL)
             {
                 if(tgt)
-                    tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+                    tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                 return 1;
             }
 
@@ -241,7 +246,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
             if(selectmode==SELECTFILE_ANY)
             {
                 if(tgt)
-                    tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+                    tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                 return 1;
             }
 
@@ -251,7 +256,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
                 if(isFile(path))
                 {
                     if(tgt)
-                        tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+                        tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                     return 1;
                 }
             }
@@ -264,7 +269,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
                     if(filebox->isItemSelected(i) && filebox->isItemFile(i))
                     {
                         if(tgt)
-                            tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+                            tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                         return 1;
                     }
                 }
@@ -278,7 +283,7 @@ long FileSelector::onCmdAccept(FXObject*,FXSelector,void*)
                     if(filebox->isItemSelected(i) && filebox->getItemFilename(i)!="..")
                     {
                         if(tgt)
-                            tgt->handle(accept,MKUINT(sel,SEL_COMMAND),(void*)1);
+                            tgt->handle(accept,FXSEL(SEL_COMMAND,sel),(void*)1);
                         return 1;
                     }
                 }
@@ -323,9 +328,9 @@ long FileSelector::onCmdDirectoryUp(FXObject*,FXSelector,void*)
 long FileSelector::onUpdDirectoryUp(FXObject* sender,FXSelector,void*)
 {
     if(FXFile::isTopDirectory(filebox->getDirectory()))
-        sender->handle(this,MKUINT(ID_DISABLE,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
     else
-        sender->handle(this,MKUINT(ID_ENABLE,SEL_COMMAND),NULL);
+        sender->handle(this,FXSEL(SEL_COMMAND,ID_ENABLE),NULL);
     return 1;
 }
 
@@ -362,8 +367,8 @@ long FileSelector::onCmdDirTree(FXObject*,FXSelector,void* ptr)
 FXString FileSelector::patternFromText(const FXString& pattern)
 {
     FXint beg,end;
-    end=pattern.findb(')');         // Search from the end so we can allow ( ) in the pattern name itself
-    beg=pattern.findb('(',end-1);
+    end=pattern.rfind(')');         // Search from the end so we can allow ( ) in the pattern name itself
+    beg=pattern.rfind('(',end-1);
     if(0<=beg && beg<end)
         return pattern.mid(beg+1,end-beg-1);
     return pattern;
@@ -545,7 +550,7 @@ void FileSelector::setPatternList(const FXString& patterns)
     FXString pat;
     FXint i;
     filefilter->clearItems();
-    for(i=0; !(pat=patterns.extract(i,'\n')).empty(); i++)
+    for(i=0; !(pat=patterns.section('\n',i)).empty(); i++)
         filefilter->appendItem(pat);
     if(!filefilter->getNumItems())
         filefilter->appendItem(allfiles);
