@@ -7,12 +7,6 @@
 class FileSelector;
 class FileList;
 class DirBox;
-class FXTextField;
-class FXComboBox;
-class FXButton;
-class FXIcon;
-class FXMenuPane;
-class FXCheckButton;
 
 /// File selection widget
 class FXAPI FileSelector : public FXPacker
