@@ -8,9 +8,9 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <fox/fx.h>
-#include <fox/fxkeys.h>
-#include <fox/FXPNGIcon.h>
+#include <fox-1.2/fx.h>
+#include <fox-1.2/fxkeys.h>
+#include <fox-1.2/FXPNGIcon.h>
 
 #include "icons.h"
 #include "FileList.h"
@@ -46,6 +46,7 @@
 #endif
 
 // Global Variables
+extern FXMainWindow *mainWindow;
 extern FXString editor;
 extern FXString viewer;
 extern FXString homelocation;
@@ -78,9 +79,10 @@ FXDEFMAP(FilePanel) FilePanelMap[]={
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_FILE_DEL,FilePanel::onCmdFileDel),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_FILE_SLINK,FilePanel::onCmdFileMan),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_OPEN_WITH,FilePanel::onCmdOpenWith),
+                               FXMAPFUNC(SEL_COMMAND,FilePanel::ID_OPEN,FilePanel::onCmdOpen),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_REFRESH,FilePanel::onRefresh),
                                FXMAPFUNC(SEL_COMMAND,FilePanel::ID_ADD_TO_ARCH,FilePanel::onCmdAddToArch),
-                               FXMAPFUNC(SEL_RIGHTBUTTONPRESS,FilePanel::ID_FILE_PANEL,FilePanel::onPopupMenu),
+                               FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,FilePanel::ID_FILE_PANEL,FilePanel::onCmdPopupMenu),
                                FXMAPFUNC(SEL_DOUBLECLICKED,FilePanel::ID_FILE_PANEL,FilePanel::onCmdItemDblClcked),
                                FXMAPFUNC(SEL_FOCUSIN,FilePanel::ID_FILE_PANEL,FilePanel::onCmdItemClcked),
                                FXMAPFUNC(SEL_UPDATE,FilePanel::ID_STATUS,FilePanel::onUpdStatus),
@@ -119,12 +121,12 @@ FilePanel::FilePanel(FXchar* nm,FXComposite *p, FXuint name_size, FXuint size_si
 	FXIcon *showhiddenicon=new FXPNGIcon(getApp(),showhidden);
 	FXIcon *hidehiddenicon=new FXPNGIcon(getApp(),hidehidden);
 
-    name=nm;
-    label=new FXLabel(this," ",NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
-    label->setTarget(this);
-    label->setSelector(MKUINT(FilePanel::ID_LABEL,0));
+    FXVerticalFrame* cont=new FXVerticalFrame(this,LAYOUT_FILL_Y|LAYOUT_FILL_X|FRAME_SUNKEN,0,0,0,0, 0,0,0,0, 1,1);
 
-    FXVerticalFrame* cont=new FXVerticalFrame(this,LAYOUT_FILL_Y|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK,0,0,0,0, 0,0,0,0);
+    name=nm;
+    label=new FXLabel(cont," ",NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_RAISED);
+    label->setTarget(this);
+    label->setSelector(FXSEL(0,FilePanel::ID_LABEL));
 
     list=new FileList(cont,this,ID_FILE_PANEL,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_BIG_ICONS);
     list->setHeaderSize(0,name_size);
@@ -135,24 +137,24 @@ FilePanel::FilePanel(FXchar* nm,FXComposite *p, FXuint name_size, FXuint size_si
     list->setHeaderSize(5,grou_size);
     list->setHeaderSize(6,attr_size);  
 
-	FXPacker* packer=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
-    new FXToggleButton(packer,_("\tShow hidden files (Ctrl-F5)"),_("\tHide hidden files (Ctrl-F5)"),showhiddenicon,hidehiddenicon,this->list,FileList::ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_LEFT|ICON_BEFORE_TEXT);
-
-    status=new FXLabel(packer,_("Status"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
-    status->setTarget(this);
-    status->setSelector(MKUINT(FilePanel::ID_STATUS,SEL_UPDATE));
+	statusbar=new FXHorizontalFrame(cont,JUSTIFY_LEFT|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);
+    new FXToggleButton(statusbar,_("\tShow hidden files (Ctrl-F5)"),_("\tHide hidden files (Ctrl-F5)"),showhiddenicon,hidehiddenicon,this->list,
+	                   FileList::ID_TOGGLE_HIDDEN,BUTTON_TOOLBAR|LAYOUT_LEFT|ICON_BEFORE_TEXT|FRAME_RAISED);
+    statusbar->setTarget(this);
+    statusbar->setSelector(FXSEL(SEL_UPDATE,FilePanel::ID_STATUS));
+    status=new FXLabel(statusbar,_("Status"),NULL,JUSTIFY_LEFT|LAYOUT_LEFT|LAYOUT_FILL_X|FRAME_SUNKEN);
 
     homelocation=getenv("HOME");
     if(homelocation=="")
         homelocation=ROOTDIR;
 	selmult=FALSE;
+	current=NULL;
 }
 
 // Create X window
 void FilePanel::create()
 {
 	FXVerticalFrame::create();
-	list->create();
 }
 
 // Destructor
@@ -163,6 +165,7 @@ FilePanel::~FilePanel()
     delete current;
     delete next;
     delete status;
+	delete statusbar;
 }
 
 
@@ -176,7 +179,6 @@ void FilePanel::focus()
     current=this;
     next->unfocus();
     list->setFocus();
-    ((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->setDirectory(current->list->getDirectory());
 }
 
 
@@ -186,7 +188,7 @@ void FilePanel::unfocus()
     label->setBackColor(FXRGB(128,128,128));
     label->setTextColor(FXRGB(255,255,255));
     current=next;
-    list->handle(this,MKUINT(FileList::ID_DESELECT_ALL,SEL_COMMAND),NULL);
+    list->handle(this,FXSEL(SEL_COMMAND,FileList::ID_DESELECT_ALL),NULL);
 }
 
 
@@ -202,7 +204,8 @@ void FilePanel::updateLocation()
 {
     FXString item;
 	FXint i=0;
-	FXComboBox* address=((XFileExplorer*) getApp()->getMainWindow())->address;
+	FXComboBox* address=((XFileExplorer*) mainWindow)->address;
+  	address->setNumVisible(5);
 	FXint count=address->getNumItems();
     FXString p=list->getDirectory();
 
@@ -214,7 +217,7 @@ void FilePanel::updateLocation()
 	}
     while(i < count)
 	{
-    	item = address->retrieveItem(i++);
+    	item = address->getItem(i++);
     	if(!strcmp((const char*)&p[0],(const char*)&item[0]))
 		{
 			i--;
@@ -229,7 +232,9 @@ void FilePanel::updateLocation()
 // Double Click on File Item
 long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
 {
-    chdir(current->list->getDirectory().text());
+    // Commented out to fix a problem with umount
+	//chdir(current->list->getDirectory().text());
+
     FXchar path[MAXPATHLEN+1],name[2048],dir[MAXPATHLEN+1],*p;
     FXString buf;
 
@@ -252,12 +257,12 @@ long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
                 return 0;
 			}
             if(dir[0]=='.' && dir[1]=='.' && dir[2]==0)// '..'  ?
-                list->handle(this,MKUINT(FileList::ID_DIRECTORY_UP,SEL_COMMAND),NULL);
+                list->handle(this,FXSEL(SEL_COMMAND,FileList::ID_DIRECTORY_UP),NULL);
             else
                 list->setDirectory(dir);
             
 			// Change directory in tree list  
-			((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->setDirectory(dir);
+			((XFileExplorer*) mainWindow)->dirpanel->list->setDirectory(dir);
 			
 			// Update location history			
 			updateLocation();
@@ -266,9 +271,9 @@ long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
         {
             FileAssoc *association=list->getItemAssoc(item);
             if(association)
-                if(association->command.extract(0,',').text() != NULL)
+                if(association->command.section(',',0).text() != NULL)
                 {
-                    FXString command=association->command.extract(0,',')+" \""+list->getItemPathname(item);
+                    FXString command=association->command.section(',',0)+" \""+list->getItemPathname(item);
                     command+="\" &";
                     system(command.text());
                 }
@@ -280,7 +285,7 @@ long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
                     system(buf.text());
                 }    // If regular file return as the selected file
                 else
-                    current->handle(this,MKUINT(ID_OPEN_WITH,SEL_COMMAND),NULL);
+                    current->handle(this,FXSEL(SEL_COMMAND,ID_OPEN_WITH),NULL);
             else if(list->isItemExecutable(item))//executable
             {
                 buf="'";
@@ -289,7 +294,7 @@ long FilePanel::onCmdItemDblClcked(FXObject* sender,FXSelector sel, void* ptr)
                 system(buf.text());
             }    // If regular file return as the selected file
             else
-                current->handle(this,MKUINT(ID_OPEN_WITH,SEL_COMMAND),NULL);
+                current->handle(this,FXSEL(SEL_COMMAND,ID_OPEN_WITH),NULL);
         }
     }
     return 1;
@@ -307,9 +312,9 @@ long FilePanel::onCmdItemClcked(FXObject* sender,FXSelector sel, void* ptr)
 // Go to parent directory
 long FilePanel::onCmdDirectoryUp(FXObject* sender,FXSelector sel, void* ptr)
 {
-    current->list->handle(this,MKUINT(FileList::ID_DIRECTORY_UP,SEL_COMMAND),NULL);
+    current->list->handle(this,FXSEL(SEL_COMMAND,FileList::ID_DIRECTORY_UP),NULL);
     current->list->setFocus();
-    ((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->setDirectory(current->list->getDirectory());
+    ((XFileExplorer*) mainWindow)->dirpanel->list->setDirectory(current->list->getDirectory());
 	updateLocation();
     return 1;
 }
@@ -320,7 +325,7 @@ long FilePanel::onCmdGoHome(FXObject* sender,FXSelector sel, void* ptr)
 {
     current->list->setDirectory(homelocation);
     current->list->setFocus();
-    ((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->setDirectory(homelocation);
+    ((XFileExplorer*) mainWindow)->dirpanel->list->setDirectory(homelocation);
 	updateLocation();
     return 1;
 }
@@ -338,11 +343,11 @@ long FilePanel::onCmdFileMan(FXObject* sender,FXSelector sel,void*)
 	// If no selected files in the file list, use the selected folder from the tree list (if any)
 	if (num==0)
 	{
-    	DirItem* item=(DirItem*)((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getCurrentItem();
+    	DirItem* item=(DirItem*)((XFileExplorer*) mainWindow)->dirpanel->list->getCurrentItem();
 		if (!item)
 			return 0;
 			
-		FXString filepath=((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getItemPathname((TreeItem*)item);	
+		FXString filepath=((XFileExplorer*) mainWindow)->dirpanel->list->getItemPathname((TreeItem*)item);	
     	target = FXFile::directory(filepath);
 		param = target+"\n"+FXStringVal(1)+"\n"+filepath;
 	}
@@ -355,7 +360,7 @@ long FilePanel::onCmdFileMan(FXObject* sender,FXSelector sel,void*)
         	if (current->list->isItemSelected (u))
         	{
             	name = current->list->getItemText(u).text();
-            	name = name.extract(0,'\t');
+            	name = name.section('\t',0);
             	if(name == "..")
             	{
                		dotdot = 1;
@@ -367,27 +372,27 @@ long FilePanel::onCmdFileMan(FXObject* sender,FXSelector sel,void*)
         	num--;
 		
 		target = current->next->list->getDirectory();
-		if(!current->next->shown() || SELID(sel)==ID_FILE_RENAME)
+		if(!current->next->shown() || FXSELID(sel)==ID_FILE_RENAME)
         	target = current->list->getDirectory();
 		param = target+"\n"+FXStringVal(num)+"\n"+sources;
 	}
 
-    switch(SELID(sel))
+    switch(FXSELID(sel))
     {
     case ID_FILE_COPY:
-        sel = MKUINT(XFileExplorer::ID_FILE_COPY,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_COPY);
         break;
     case ID_FILE_MOVE:
-        sel = MKUINT(XFileExplorer::ID_FILE_MOVE,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_MOVE);
         break;
     case ID_FILE_RENAME:
-        sel = MKUINT(XFileExplorer::ID_FILE_RENAME,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_RENAME);
         break;
     case ID_FILE_SLINK:
-        sel = MKUINT(XFileExplorer::ID_FILE_SLINK,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_SLINK);
         break;
     }
-    getApp()->getMainWindow()->handle(this,sel,strdup(param.text()));
+    mainWindow->handle(this,sel,strdup(param.text()));
     return 1;
 }
 
@@ -413,18 +418,18 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
     // If no selected files, use the selected folder from the tree list (if any)
 	if(num==0)
 	{
-    	DirItem* item=(DirItem*)((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getCurrentItem();
+    	DirItem* item=(DirItem*)((XFileExplorer*) mainWindow)->dirpanel->list->getCurrentItem();
 		if (!item)
 			return 0;
 			
-		FXString filepath=((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getItemPathname((TreeItem*)item);
+		FXString filepath=((XFileExplorer*) mainWindow)->dirpanel->list->getItemPathname((TreeItem*)item);
 
     	if(confirm_del)
     	{
         	FXPNGIcon icon(getApp(),delete_big);
 			FXString message=_("Delete folder ") + filepath + " ?";
-         	MessageBox box(this,_("Confirm Delete"),message,&icon,MBOX_YES_NO|DECOR_TITLE|DECOR_BORDER);
-       		if(box.execute() != MBOX_CLICKED_YES)
+         	MessageBox box(this,_("Confirm Delete"),message,&icon,MBOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+       		if(box.execute() != MBOX_CLICKED_OK)
             	return 0;
    		}
 
@@ -445,7 +450,7 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
 
     	// Return to parent dir in DirList		
 		FXString parentdir=FXFile::directory(dir);
-		((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->setDirectory(parentdir);
+		((XFileExplorer*) mainWindow)->dirpanel->list->setDirectory(parentdir);
     	chdir(parentdir.text());
 
 		getApp()->endWaitCursor();
@@ -463,8 +468,8 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
 				message=_("  Delete selected item ?  ");
 			else
 				message=_("  Delete all selected items ?  ");
-			MessageBox box(this,_("Confirm Delete"),message,&icon,MBOX_YES_NO|DECOR_TITLE|DECOR_BORDER);
-        	if(box.execute() != MBOX_CLICKED_YES)
+			MessageBox box(this,_("Confirm Delete"),message,&icon,MBOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);
+        	if(box.execute() != MBOX_CLICKED_OK)
             	return 0;
    		}
 
@@ -499,9 +504,9 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
     			{
 					// Get process uid and file uid
 					FXuint uid=getuid();
-					struct stat status;
-					lstat(filepath.text(),&status);
-					FXuint fileuid=status.st_uid;
+					struct stat buf;
+					lstatout(filepath.text(),&buf);
+					FXuint fileuid=buf.st_uid;
 					
 					// If it is a file and we are owner of it
 					if (isFile(filepath) && fileuid==uid)
@@ -588,7 +593,7 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
 
 	// Force FilePanel and DirPanel refresh
    	onRefresh(0,0,0);
-	((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->onRefresh(0,0,0);
+	((XFileExplorer*) mainWindow)->dirpanel->list->onRefresh(0,0,0);
 	
     return 1;
 }
@@ -597,6 +602,7 @@ long FilePanel::onCmdFileDel(FXObject*,FXSelector,void*)
 // Add files or directory to an archive
 long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 {
+    FXString ext1, ext2, cmd, archive="";
     static char history[ADD_TO_ARCH_HIST_SIZE][100];
     static int n=0;
     int i;
@@ -609,9 +615,8 @@ long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 
     FXchar name[MAXPATHLEN+1],*p;
     HistInputDialog* dialog;
-    FXString archive=current->list->getDirectory();
+    FXString archpath=current->list->getDirectory();
 
-    FXString command="/bin/tar -zcvf ";
     dialog = new HistInputDialog(this,archive,_("Create new archive: (e.g. archive.tar.gz)"),_("Add To Archive"));
 
     for(int i=0;i<n;i++)
@@ -620,15 +625,35 @@ long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
     if(dialog->execute())
     {
         // Get string and preserve escape characters
-		archive="\""+dialog->getText()+"\"";
+		archive=archpath+PATHSEPSTRING+"\""+dialog->getText()+"\"";
 
-        // Handle zip and bz2 archives
-        if (strstr(archive.text(),".zip") != NULL || strstr(archive.text(),".ZIP") != NULL)
-            command="/usr/bin/zip -r ";
-        else if (strstr(archive.text(),".bz2") != NULL || strstr(archive.text(),".tbz2") != NULL)
-            command="/bin/tar -jcvf ";
-
-        command+=archive+" ";
+        // Get extensions of the archive name
+        ext1=dialog->getText().rafter('.',1);
+        ext2=dialog->getText().rafter('.',2);
+		
+		// Handle different archive formats
+		if (ext2=="tar.gz" || ext2=="TAR.GZ")
+            cmd="/bin/tar -zcvf "+archive+" ";
+		else if (ext2=="tar.bz2" || ext2=="TAR.BZ2")
+            cmd="/bin/tar -jcvf "+archive+" ";
+		else if (ext2=="tar.Z" || ext2=="TAR.Z")
+           	cmd="/bin/tar -Zcvf "+archive+" ";
+		else if (ext1=="tar" || ext1=="TAR")
+           	cmd="/bin/tar -cvf "+archive+" ";
+		else if (ext1=="gz" || ext1=="GZ")
+			cmd="/usr/bin/gzip -v ";				
+		else if (ext1=="tgz" || ext1=="TGZ")
+            cmd="/bin/tar -zcvf "+archive+" ";
+		else if (ext1=="bz2" || ext1=="BZ2")
+			cmd="/usr/bin/bzip2 -v ";				
+		else if (ext1=="tbz2" || ext1=="TBZ2")
+            cmd="/bin/tar -jcvf "+archive+" ";
+		else if (ext1=="Z")
+            cmd="/usr/bin/compress -v ";
+		else if (ext1=="zip" || ext1=="ZIP")
+            cmd="/usr/bin/zip -r "+archive+" ";
+		else
+			cmd="/bin/tar -zcvf "+archive+" ";
 
         for (int u= 0; u< current->list->getNumItems (); u++)
             if (current->list->isItemSelected (u))
@@ -640,9 +665,9 @@ long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 				// Don't include '..' in the list
 				if (strcmp(name,"..")!=0)
 				{
-                	command+=" ";
-                	command=command+"\""+name+"\"";
-                	command+=" ";
+                	cmd+=" ";
+                	cmd=cmd+"\""+name+"\"";
+                	cmd+=" ";
 				}
             }
 					
@@ -652,9 +677,9 @@ long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 		// File object
 		f=new File(getApp(),_("Create archive"),ARCHIVE);
 		f->create();
-				   
+
 		// Create archive
-		f->archive(archive,command);
+		f->archive(archive,cmd);
  
 		getApp()->endWaitCursor();
 		delete f; 
@@ -665,15 +690,15 @@ long FilePanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
         // Manage dialog history size
 		n=dialog->getHistorySize();
         n++;
-        command=dialog->getText();
+        cmd=dialog->getText();
         if(n>ADD_TO_ARCH_HIST_SIZE)
             n=ADD_TO_ARCH_HIST_SIZE;
         for(i=0;i<n-1;i++)
-            if(!strcmp(history[i],command.text()))
+            if(!strcmp(history[i],cmd.text()))
                 break;
         if(i==n-1)
         {
-            strcpy(history[0],command.text());
+            strcpy(history[0],cmd.text());
             for(i=1;i<n;i++)
                 strcpy(history[i],dialog->getHistoryItem(i-1).text());
         }
@@ -700,7 +725,7 @@ long FilePanel::onCmdEdit(FXObject*,FXSelector s,void*)
 		return 0;
 
     FXString command;
-    if(SELID(s)==ID_EDIT)
+    if(FXSELID(s)==ID_EDIT)
         command = editor;
     else
         command = viewer;
@@ -708,15 +733,15 @@ long FilePanel::onCmdEdit(FXObject*,FXSelector s,void*)
 	FileAssoc *association=current->list->getItemAssoc(itm);
 	if(association)
 	{
-		if(SELID(s)==ID_EDIT)
+		if(FXSELID(s)==ID_EDIT)
 		{
-			command=association->command.extract(2,',');
+			command=association->command.section(',',2);
 			if(command.length()==0)
 				command = editor;
 		}
 		else
 		{
-			command=association->command.extract(1,',');
+			command=association->command.section(',',1);
 			if(command.length()==0)
 				command = viewer;
 		}
@@ -750,11 +775,11 @@ long FilePanel::onCmdProperties(FXObject* sender,FXSelector,void*)
 	// If no selected files in the file list, use the selected folder from the tree list (if any)
 	if (num==0)
 	{
-    	DirItem* item=(DirItem*)((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getCurrentItem();
+    	DirItem* item=(DirItem*)((XFileExplorer*) mainWindow)->dirpanel->list->getCurrentItem();
 		if (!item)
 			return 0;
 			
-		FXString filepath=((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getItemPathname((TreeItem*)item);
+		FXString filepath=((XFileExplorer*) mainWindow)->dirpanel->list->getItemPathname((TreeItem*)item);
     	FXString path=FXFile::directory(filepath);
     	FXString filename=FXFile::name(filepath);
         PropertiesBox* attrdlg = new PropertiesBox(this,filename,path);
@@ -772,7 +797,7 @@ long FilePanel::onCmdProperties(FXObject* sender,FXSelector,void*)
     {
     	FXString path=current->list->getDirectory();
         FXString filename = current->list->getItemText(itm);
-        filename=filename.extract(0,'\t');
+        filename=filename.section('\t',0);
         PropertiesBox* attrdlg = new PropertiesBox(this,filename,path);
         if(attrdlg->execute())
         {
@@ -793,7 +818,7 @@ long FilePanel::onCmdProperties(FXObject* sender,FXSelector,void*)
         for (int u= 0; u< current->list->getNumItems (); u++)
             if (current->list->isItemSelected (u))
             {
-                files[i] = current->list->getItemText(u).extract(0,'\t');
+                files[i] = current->list->getItemText(u).section('\t',0);
                 i++;
             }
 
@@ -813,39 +838,20 @@ long FilePanel::onCmdProperties(FXObject* sender,FXSelector,void*)
 // Create new directory
 long FilePanel::onCmdNewDir(FXObject*,FXSelector,void*)
 {
-    current->list->setFocus();
-    FXString dirname = current->list->getDirectory();
-    if(dirname!=ROOTDIR)
-        dirname+=PATHSEPSTRING;
-    FXString olddir=dirname;
+	// Current item
+	current->list->setFocus();
+
+    FXString dirname="";	
+    FXString dirpath = current->list->getDirectory();
+    if(dirpath!=ROOTDIR)
+        dirpath+=PATHSEPSTRING;
+
     InputDialog* dialog = new InputDialog(this,dirname,_("Create new folder..."),_("New Folder"));
     dialog->CursorEnd();
     if(dialog->execute())
     {
-        dirname=dialog->getText();
-		
-		// Test some error conditions
-		if (exists(dequote(dirname)))
-        {
-			MessageBox::error(this,MBOX_OK,_("Error"),_("File or folder %s already exists"), dirname.text());
-        	return 0;
-		}
-		FXString parentdir;
-		if (FXFile::name(dirname)=="")
-			parentdir=FXFile::directory(FXFile::directory(dirname));
-		else			
-			parentdir=FXFile::directory(dirname);
-		if (!exists(dequote(parentdir)))
-        {
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Folder %s doesn't exist"), parentdir.text());
-        	return 0;
-		}
-		if (!FXFile::isWritable(parentdir))
-		{
-         	MessageBox::error(this,MBOX_OK,_("Error"),_("Can't write to %s : Permission denied"), parentdir.text());
-        	return 0;
-		}
-        if(olddir!=dirname)
+		dirname=dirpath+dialog->getText();
+        if(dirname!=dirpath)
         {
 			// Create the new dir
 			FXint ret=mkdir(dirname.text(),0755);
@@ -853,8 +859,8 @@ long FilePanel::onCmdNewDir(FXObject*,FXSelector,void*)
 			{
          		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
     			return 0;
-			}								
-        }
+			}
+		}							
     }
     delete dialog;
 	
@@ -867,49 +873,36 @@ long FilePanel::onCmdNewDir(FXObject*,FXSelector,void*)
 // Create new file
 long FilePanel::onCmdNewFile(FXObject*,FXSelector,void*)
 {
+	// Current item
     current->list->setFocus();
-    FXString pathname = current->list->getDirectory();
-    if(pathname!=ROOTDIR)
-        pathname+=PATHSEPSTRING;
-    FXString oldpath=pathname;
-    InputDialog* dialog = new InputDialog(this,pathname,_("Create new file..."),_("New File"));
+
+    FXString filename="";	
+    FXString filepath = current->list->getDirectory();
+    if(filepath!=ROOTDIR)
+        filepath+=PATHSEPSTRING;
+
+    InputDialog* dialog = new InputDialog(this,filename,_("Create new file..."),_("New File"));
     dialog->CursorEnd();
     if(dialog->execute())
     {
-        pathname=dialog->getText();
-		
-		// Test some error conditions
-		if (exists(dequote(pathname)))
-        {
-			MessageBox::error(this,MBOX_OK,_("Error"),_("File or folder %s already exists"), pathname.text());
-        	return 0;
-		}
-		FXString parentdir;
-		if (FXFile::name(pathname)=="")
-			parentdir=FXFile::directory(FXFile::directory(pathname));
-		else			
-			parentdir=FXFile::directory(pathname);
-		if (!exists(dequote(parentdir)))
-        {
-			MessageBox::error(this,MBOX_OK,_("Error"),_("Folder %s doesn't exist"), parentdir.text());
-        	return 0;
-		}
-		if (!FXFile::isWritable(parentdir))
-		{
-         	MessageBox::error(this,MBOX_OK,_("Error"),_("Can't write to %s : Permission denied"), parentdir.text());
-        	return 0;
-		}
-        if(oldpath!=pathname)
+		filename=filepath+dialog->getText();
+        if(filename!=filepath)
         {
+			// Test some error conditions
+			if (exists(dequote(filename)))
+        	{
+				MessageBox::error(this,MBOX_OK,_("Error"),_("File or folder %s already exists"), filename.text());
+        		return 0;
+			}
 			// Create the new file
-			FILE *file=fopen(pathname.text(),"w");
+			FILE *file=fopen(filename.text(),"w+");
 			if (file==NULL)
 			{
          		MessageBox::error(this,MBOX_OK,_("Error"),"%s",strerror(errno));
     			return 0;
 			}
 			fclose(file);								
-        }
+		}							
     }
     delete dialog;
 	
@@ -929,13 +922,13 @@ long FilePanel::onCmdPaste(FXObject*,FXSelector sel,void*)
     switch(clptype)
     {
     case COPY_CLP:
-        sel = MKUINT(XFileExplorer::ID_FILE_COPY,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_COPY);
         break;
     case CUT_CLP:
-        sel = MKUINT(XFileExplorer::ID_FILE_CUT,SEL_COMMAND);
+        sel = FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_CUT);
         break;
     }
-    getApp()->getMainWindow()->handle(this,sel,strdup(param.text()));
+    mainWindow->handle(this,sel,strdup(param.text()));
     clipboard = "";
 
 	// Force panel refresh
@@ -951,7 +944,7 @@ long FilePanel::onCmdClp(FXObject*,FXSelector sel,void*)
 
     // Clipboard type
 	clipboard = "";
-	if (SELID(sel)==ID_CUT_CLP)
+	if (FXSELID(sel)==ID_CUT_CLP)
 		clptype=CUT_CLP;
 	else
 		clptype=COPY_CLP;
@@ -962,11 +955,11 @@ long FilePanel::onCmdClp(FXObject*,FXSelector sel,void*)
     // If no selected files, use the selected folder from the tree list (if any)
 	if (num==0)
 	{
-    	DirItem* item=(DirItem*)((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getCurrentItem();
+    	DirItem* item=(DirItem*)((XFileExplorer*) mainWindow)->dirpanel->list->getCurrentItem();
 		if (!item)
 			return 0;
 			
-		FXString pathname=((XFileExplorer*) getApp()->getMainWindow())->dirpanel->list->getItemPathname((TreeItem*)item);
+		FXString pathname=((XFileExplorer*) mainWindow)->dirpanel->list->getItemPathname((TreeItem*)item);
 		clipboard = FXStringVal(1)+"\n"+pathname;
 	}
 
@@ -980,7 +973,7 @@ long FilePanel::onCmdClp(FXObject*,FXSelector sel,void*)
         	if (current->list->isItemSelected (u))
         	{
             	name = current->list->getItemText(u).text();
-            	name = name.extract(0,'\t');
+            	name = name.section('\t',0);
             	if(name == "..")
             	{
                 	dotdot = 1;
@@ -994,6 +987,67 @@ long FilePanel::onCmdClp(FXObject*,FXSelector sel,void*)
 }
 
 
+// Open
+long FilePanel::onCmdOpen(FXObject*,FXSelector,void*)
+{
+    FXString pathname, command;
+	FileAssoc* association;
+	   
+	current->list->setFocus();
+    chdir(current->list->getDirectory().text());
+
+	if (current->list->getNumSelectedItems()==0)
+		return 0;
+    
+	for (int u= 0; u< current->list->getNumItems (); u++)
+	{
+		if (current->list->isItemSelected (u))
+		{
+			pathname=current->list->getItemPathname(u);
+			association = current->list->getItemAssoc(u);
+			
+			// If there is an association
+			if(association)
+			{
+                // Use it to open the file
+				if(association->command.section(',',0).text() != NULL)
+                {
+                    command=association->command.section(',',0)+" \""+pathname;
+                    command+="\" &";
+                    system(command.text());
+                }
+                
+				// or execute it
+				else if(current->list->isItemExecutable(u))
+                {
+                    command="'";
+                    command+=pathname;
+                    command+="' &";
+                    system(command.text());
+                }
+                
+				// or call the "Open with..." dialog
+				else
+                    current->handle(this,FXSEL(SEL_COMMAND,ID_OPEN_WITH),NULL);
+			}
+            
+			// If no association but executable
+			else if(current->list->isItemExecutable(u))
+            {
+                command="'";
+                command+=pathname;
+                command+="' &";
+                system(command.text());
+            }
+			
+			// Other cases
+            else
+                current->handle(this,FXSEL(SEL_COMMAND,ID_OPEN_WITH),NULL);
+		}
+	}
+    return 1;
+}
+
 // Open with
 long FilePanel::onCmdOpenWith(FXObject*,FXSelector,void*)
 {
@@ -1034,7 +1088,7 @@ long FilePanel::onCmdOpenWith(FXObject*,FXSelector,void*)
                     {
                         // Update existing association
                         FXString oldfileassoc = getApp()->reg().readStringEntry("FILETYPES", ext.text(),"");
-                        oldfileassoc.remove(0, oldfileassoc.extract(0,';').extract(0,',').size()-1);
+						oldfileassoc.remove(0, oldfileassoc.section(';',0).section(',',0).length()-1);
                         oldfileassoc.prepend(dialog->getText());
                         getApp()->reg().writeStringEntry("FILETYPES", ext.text(), oldfileassoc.text());
 
@@ -1044,7 +1098,7 @@ long FilePanel::onCmdOpenWith(FXObject*,FXSelector,void*)
 						str[1]=new char[strlen(oldfileassoc.text())+1];
 						strcpy(str[0],ext.text());
 						strcpy(str[1],oldfileassoc.text());
-						getApp()->getMainWindow()->handle(this, MKUINT(XFileExplorer::ID_FILE_ASSOC,SEL_COMMAND), str);
+						mainWindow->handle(this, FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_ASSOC), str);
                     }
                     else
                     {
@@ -1058,7 +1112,7 @@ long FilePanel::onCmdOpenWith(FXObject*,FXSelector,void*)
 						str[1]=new char[strlen(command.text())+1];
 						strcpy(str[0],ext.text());
 						strcpy(str[1],command.text());
-						getApp()->getMainWindow()->handle(this, MKUINT(XFileExplorer::ID_FILE_ASSOC,SEL_COMMAND),str);
+						mainWindow->handle(this, FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_ASSOC),str);
                     }
                 }
                 // End
@@ -1151,7 +1205,7 @@ long FilePanel::onCmdItemFilter(FXObject*,FXSelector,void*)
 
 
 // File list context menu
-long FilePanel::onPopupMenu(FXObject* o,FXSelector s,void* p)
+long FilePanel::onCmdPopupMenu(FXObject* o,FXSelector s,void* p)
 {
     // FilePanel focus
 	focus();
@@ -1182,20 +1236,24 @@ long FilePanel::onPopupMenu(FXObject* o,FXSelector s,void* p)
 
 	// If control key was pressed, deselect all items
 	if(ctrlkey)
-		list->handle(o,MKUINT(FileList::ID_DESELECT_ALL,SEL_COMMAND),p);
+		list->handle(o,FXSEL(SEL_COMMAND,FileList::ID_DESELECT_ALL),p);
 
-	getApp()->getMainWindow()->handle(this,MKUINT(XFileExplorer::ID_MENU,SEL_COMMAND),(void*)list->getCurrentItem());
+	mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_MENU),(void*)list->getCurrentItem());
+	
     return 1;
 }
 
 
-// FilePanel refresh
+// FilePanel and DirPanel refresh
 long FilePanel::onRefresh(FXObject*,FXSelector,void*)
 {
+	getApp()->beginWaitCursor();
     current->list->setFocus();
     FXString dir=current->list->getDirectory();
     current->list->setDirectory(ROOTDIR);
     current->list->setDirectory(dir);
+	((XFileExplorer*) mainWindow)->dirpanel->list->onRefresh(0,0,0);
+	getApp()->endWaitCursor();
     return 1;
 }
 
@@ -1216,7 +1274,7 @@ long FilePanel::onCmdMount(FXObject*,FXSelector sel,void*)
 	if (isLink(dir))
 		dir=readlink(dir);
 
-    if(SELID(sel)==ID_MOUNT)
+    if(FXSELID(sel)==ID_MOUNT)
     {
         op=MOUNT;
 		msg=_("Mount");
@@ -1236,19 +1294,19 @@ long FilePanel::onCmdMount(FXObject*,FXSelector sel,void*)
 	getApp()->beginWaitCursor();
 
 	// File object
-	text=msg + " file system...";
+	text=msg + _(" file system...");
 	f=new File(getApp(),text.text(),op);
 	f->create();
 				   
 	// Mount/unmount file system
-	text=msg + " the directory :";
+	text=msg + _(" the directory :");
 	f->mount(dir,text,cmd,op);
  
 	// If action is cancelled in progress dialog
 	if (f->isCancelled)
 	{
 		f->hide();
-		text=msg + " operation cancelled!";
+		text=msg + _(" operation cancelled!");
 		MessageBox::error(this,MBOX_OK,_("Error"),text.text());
 		delete f;
 		return 0;
@@ -1269,15 +1327,13 @@ long FilePanel::onUpdMount(FXObject* o,FXSelector sel,void*)
 {
     // Current directory
 	FXString dir=current->list->getDirectory();
-
-	// If symbolic link, read the linked directory
 	if (isLink(dir))
 		dir=readlink(dir);
 
     if(devices->find(dir.text()))
-        o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+        o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
     else
-        o->handle(this,MKUINT(FXWindow::ID_DISABLE,SEL_COMMAND),NULL);
+        o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
     return 1;
 }
 
@@ -1349,25 +1405,25 @@ long FilePanel::onUpdStatus(FXObject* sender,FXSelector,void*)
     item = list->getCurrentItem();
     if(num>1)
     {
-        long sz=0;
+        unsigned long long sz=0;
         size=_("0 bytes");
 
         for (int u= 0; u< list->getNumItems (); u++)
             if (list->isItemSelected (u))
             {
 				sz+=list->getItemFileSize(u);
-				sprintf(hsize,"%ld",sz);
-				::Size(hsize,hsize);
+				sprintf(hsize,"%llu",sz);
+				::hSize(hsize,hsize);
 				size=hsize;
             }
-        status->setText(size+" in "+FXStringVal(num)+" selected files");
+        status->setText(size+_(" in ")+FXStringVal(num)+_(" selected files"));
         return 0;
     }
 
     if(item<0)
     {
         num=list->getNumItems();
-        status->setText(FXStringVal(num-1)+" Items");
+        status->setText(FXStringVal(num-1)+_(" Items"));
     }
     else
     {
@@ -1382,7 +1438,7 @@ long FilePanel::onUpdStatus(FXObject* sender,FXSelector,void*)
         if((p=strchr(file,'\t')))
         {
             *p=0;
-			sprintf(hsize,"%lu",list->getItemFileSize(item));			
+			sprintf(hsize,"%llu",list->getItemFileSize(item));			
             file=p+1;
         }
         if((p=strchr(file,'\t')))
@@ -1421,7 +1477,7 @@ long FilePanel::onUpdStatus(FXObject* sender,FXSelector,void*)
         }
         else
         {
-            ::Size(hsize,hsize);
+            ::hSize(hsize,hsize);
             size=hsize;
             status->setText(usr+","+grp+" "+perm+" ("+size+") ");
         }
@@ -1466,12 +1522,12 @@ long FilePanel::onUpdUp(FXObject* o,FXSelector,void*)
     if(style & BUTTON_TOOLBAR)
     {
         if(current->list->getDirectory()!=ROOTDIR)
-            o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+            o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
         else
-            o->handle(this,MKUINT(FXWindow::ID_DISABLE,SEL_COMMAND),NULL);
+            o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
     }
     else
-        o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+        o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
     return 1;
 }
 
@@ -1483,12 +1539,12 @@ long FilePanel::onUpdPaste(FXObject* o,FXSelector,void*)
     if(style & BUTTON_TOOLBAR)
     {
         if(!clipboard.empty())
-            o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+            o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
         else
-            o->handle(this,MKUINT(FXWindow::ID_DISABLE,SEL_COMMAND),NULL);
+            o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
     }
     else
-        o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+        o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
 
     return 1;
 }
@@ -1499,13 +1555,13 @@ long FilePanel::onUpdMenu(FXObject* o,FXSelector,void*)
 {
    	// Menu item is disabled when nothing is selected
 	FXint num=current->list->getNumSelectedItems();
-	DirPanel* dirpanel=((XFileExplorer*) getApp()->getMainWindow())->dirpanel;
+	DirPanel* dirpanel=((XFileExplorer*) mainWindow)->dirpanel;
 	DirItem* item=(DirItem*)dirpanel->list->getCurrentItem();
 	
 	if ((dirpanel->shown() && item) || (num>=1))
-		o->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
 	else
-		o->handle(this,MKUINT(FXWindow::ID_DISABLE,SEL_COMMAND),NULL);
+		o->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
 
     return 1;
 }
@@ -1516,13 +1572,13 @@ long FilePanel::onUpdSelMult(FXObject* sender,FXSelector,void*)
 {
    	// Menu item is disabled when nothing is selected or multiple selection
 	FXint num=current->list->getNumSelectedItems();
-	DirPanel* dirpanel=((XFileExplorer*) getApp()->getMainWindow())->dirpanel;
+	DirPanel* dirpanel=((XFileExplorer*) mainWindow)->dirpanel;
 	DirItem* item=(DirItem*)dirpanel->list->getCurrentItem();
 	
 	if (current->selmult || (num==0 && !item) || (!dirpanel->shown() && num==0))
-		sender->handle(this,MKUINT(FXWindow::ID_DISABLE,SEL_COMMAND),NULL);
+		sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_DISABLE),NULL);
   	else
-    	sender->handle(this,MKUINT(FXWindow::ID_ENABLE,SEL_COMMAND),NULL);
+    	sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_ENABLE),NULL);
 
 	return 1;
 }
