@@ -20,6 +20,7 @@ protected:
     FileList*	  	list;
     FilePanel*		next;
     FXLabel*		label;
+	FXPacker* 		statusbar;
     FXLabel*		status;
     FXString 		name;
 	FXbool			ctrlkey;
@@ -55,6 +56,7 @@ public:
         ID_COPY_CLP,
         ID_CUT_CLP,
         ID_PASTE_CLP,
+        ID_OPEN,
         ID_OPEN_WITH,
         ID_FILTER,
         ID_STATUS,
@@ -84,9 +86,10 @@ public:
     long onCmdFileDel(FXObject*,FXSelector,void*);
     long onCmdNewDir(FXObject*,FXSelector,void*);
     long onCmdNewFile(FXObject*,FXSelector,void*);
+	long onCmdOpen(FXObject*,FXSelector,void*);
     long onCmdOpenWith(FXObject*,FXSelector,void*);
     long onRefresh(FXObject*,FXSelector,void*);
-    long onPopupMenu(FXObject*,FXSelector,void*);
+    long onCmdPopupMenu(FXObject*,FXSelector,void*);
     long onUpdUp(FXObject*,FXSelector,void*);
     long onUpdPaste(FXObject*,FXSelector,void*);
     long onCmdAddToArch(FXObject*,FXSelector,void*);
