@@ -22,7 +22,7 @@ public:
 		field->onCmdCursorEnd(0,0,0);
         field->setFocus();
     }
-    MyComboBox(FXComposite *p,FXint cols,FXint nvis,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0);
+    MyComboBox(FXComposite *p,FXint cols,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0);
 };
 
 class HistInputDialog : public DialogBox
