@@ -3,8 +3,8 @@
 #include "config.h"
 #include "i18n.h"
 
-#include <fox/fx.h>
-#include <fox/fxkeys.h>
+#include <fox-1.2/fx.h>
+#include <fox-1.2/fxkeys.h>
 
 #include "FileDialog.h"
 #include "Preferences.h"
@@ -25,12 +25,19 @@ FXbool Theme::operator != (const Theme& t)
     return FALSE;
 }
 
+// Main window
+extern FXMainWindow *mainWindow;
+
 // Global Flags
 FXbool confirm_quit;
 FXbool confirm_del;
 FXbool confirm_overwrite;
 FXbool ask_before_copy;
 FXbool warn_if_root;
+#if defined(linux)
+FXbool mount_warn;
+#endif
+FXbool display_thumbnails;
 
 // Map
 FXDEFMAP(PreferencesBox) PreferencesMap[]={
@@ -78,18 +85,18 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     // Contents
     FXHorizontalFrame *contents=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);
 
-    // Cancel
-    new FXButton(buttons,_("&Cancel"),NULL,this,ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
-    
 	// Accept
     FXButton *ok = new FXButton(buttons,_("&Accept"),NULL,this,PreferencesBox::ID_ACCEPT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
     ok->addHotKey(KEY_Return);
     
+    // Cancel
+    new FXButton(buttons,_("&Cancel"),NULL,this,ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+    
 	// Switcher
     FXTabBook *tabbook = new FXTabBook(contents,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);
 
-    // First item is Options
-    new FXTabItem(tabbook,_("O&ptions"),NULL);
+    // First tab - Programs
+    new FXTabItem(tabbook,_("&Programs"),NULL);
     FXVerticalFrame *programs=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
     FXGroupBox *group=new FXGroupBox(programs,_("Programs"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
     FXMatrix *matrix = new FXMatrix(group,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -125,17 +132,23 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     oldcfm=getApp()->reg().readStringEntry("PROGS","cfm","xterm -e mc -x");
     cfm->setText(oldcfm);
 
-    // Second tab - Confirmations
-    new FXTabItem(tabbook,_("C&onfirmation"),NULL);
-    FXVerticalFrame *confirm=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
-
-    group=new FXGroupBox(confirm,NULL,GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    // Second tab - Options
+    new FXTabItem(tabbook,_("&Options"),NULL);
+    FXVerticalFrame *options=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+    group=new FXGroupBox(options,"Confirmation",GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     quit=new FXCheckButton(group,_("Confirm quit"));
     del=new FXCheckButton(group,_("Confirm delete"));
     overwrite=new FXCheckButton(group,_("Confirm overwrite"));
     ask=new FXCheckButton(group,_("Always ask before file operation"));
+    group=new FXGroupBox(options,_("Warnings"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+#if defined(linux)
+    mount=new FXCheckButton (group,_("Warn when mount points are not responding"));
+#endif
     root_warn=new FXCheckButton (group,_("Warn if running as root"));
 
+    group=new FXGroupBox(options,"Images",GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    thumbnails=new FXCheckButton (group,_("Display images as thumbnails"));
+
     if(getuid())//running as a user?
         root_warn->disable();
     else
@@ -145,6 +158,10 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     del->setCheck(confirm_del);
     overwrite->setCheck(confirm_overwrite);
     ask->setCheck(ask_before_copy);
+#if defined(linux)
+	mount->setCheck(mount_warn);
+#endif
+	thumbnails->setCheck(display_thumbnails);
 
     // Third tab - Visual
     new FXTabItem(tabbook,_("Co&lors"),NULL);
@@ -152,7 +169,8 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
     FXGroupBox *colors=new FXGroupBox(visual,_("Colors"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
     FXHorizontalFrame *col=new FXHorizontalFrame(colors,LAYOUT_FILL_X);
 
-    colorsBox = new FXComboBox(col,8,5,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_SIDE_RIGHT);
+    colorsBox = new FXComboBox(col,8,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_SIDE_RIGHT);
+  	colorsBox->setNumVisible(5);
     FXPacker *pack = new FXPacker(col,LAYOUT_SIDE_LEFT|FRAME_SUNKEN|LAYOUT_FILL_Y);
     cwell = new FXButton(pack,"",NULL,this,ID_COLOR,LAYOUT_FIX_WIDTH|LAYOUT_FILL_Y,0,0, 30);
 
@@ -166,27 +184,28 @@ PreferencesBox::PreferencesBox(FXWindow *win): FXDialogBox(win,_("Preferences"),
 
     FXGroupBox *themes=new FXGroupBox(visual,_("Color Theme"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);//|LAYOUT_FILL_Y);
     pack = new FXPacker(themes,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_Y|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
-    themesList = new FXList(pack,4,this,ID_THEME,LIST_SINGLESELECT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    for(int i=0;i<THEMES_NUM;i++)
+    themesList = new FXList(pack,this,ID_THEME,LIST_SINGLESELECT|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    themesList->setNumVisible(5);
+	for(int i=0;i<THEMES_NUM;i++)
         themesList->appendItem(Themes[i].name);
     themesList->setCurrentItem(0);
 
     // Fourth tab - Fonts
     new FXTabItem(tabbook,_("&Fonts"),NULL);
     FXVerticalFrame *fonts=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
-    FXGroupBox *fgroup=new FXGroupBox(fonts,NULL,GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    FXGroupBox *fgroup=new FXGroupBox(fonts,_("Fonts"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
     FXMatrix *fmatrix = new FXMatrix(fgroup,3,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     new FXLabel(fmatrix,_("Normal font:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     normalfont = new FXTextField(fmatrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     new FXButton(fmatrix,_(" Select..."),NULL,this,ID_NORMALFONT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);//,0,0,0,0,20,20);
-    oldnormalfont=getApp()->reg().readStringEntry("SETTINGS","font","[helvetica] 100 500 1 0 0 0");
+    oldnormalfont=getApp()->reg().readStringEntry("SETTINGS","font","Helvetica,100,normal,regular");
     normalfont->setText(oldnormalfont);
 
     new FXLabel(fmatrix,_("Text font:"),NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     textfont = new FXTextField(fmatrix,30,NULL,0,FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
 	new FXButton(fmatrix,_(" Select..."),NULL,this,ID_TEXTFONT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);//0,0,0,0,20,20);
-    oldtextfont=getApp()->reg().readStringEntry("SETTINGS","textfont","[helvetica] 100 500 1 0 0 0");
+    oldtextfont=getApp()->reg().readStringEntry("SETTINGS","textfont","Helvetica,100,normal,regular");
     textfont->setText(oldtextfont);
 }
 
@@ -253,7 +272,7 @@ long PreferencesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
     if(browse.execute())
     {
         char *path=strdup(browse.getFilename().text());
-        switch(SELID(s))
+        switch(FXSELID(s))
         {
         case ID_BROWSE_VIEW:
             viewer->setText(FXFile::name(path).text());
@@ -274,18 +293,24 @@ long PreferencesBox::onCmdNormalFont(FXObject*,FXSelector,void*)
 {
     FXFontDialog fontdlg(this,_("Change Normal Font"),DECOR_BORDER|DECOR_TITLE);
     FXFontDesc fontdesc;
-    char fontspec[200];
-    fxparsefontdesc(fontdesc,getApp()->reg().readStringEntry("SETTINGS","font","[helvetica] 100 500 1 0 0 0"));
-    fontdlg.setFontSelection(fontdesc);
+	FXString fontspec;
+
+	fontspec=getApp()->reg().readStringEntry("SETTINGS","font","Helvetica,100,normal,regular");
+   	FXFont* nfont=new FXFont(getApp(),fontspec);
+	nfont->getFontDesc(fontdesc);
+    
+	fontdlg.setFontSelection(fontdesc);
     if(fontdlg.execute())
     {
         fontdlg.getFontSelection(fontdesc);
-        fxunparsefontdesc(fontspec,fontdesc);
+		nfont->setFontDesc(fontdesc);
+		fontspec=nfont->getFont();
         normalfont->setText(fontspec);
-        if(MBOX_CLICKED_NO!=MessageBox::question(this,MBOX_YES_NO,_("Restart"),_("Normal font will be changed after restart.\nRestart X File Explorer now?")))
+        if(MBOX_CLICKED_CANCEL!=MessageBox::question(this,MBOX_OK_CANCEL,_("Restart"),_("Normal font will be changed after restart.\nRestart X File Explorer now?")))
 		{
-        	getApp()->reg().writeStringEntry("SETTINGS","font",fontspec);
-            getApp()->getMainWindow()->handle(this,MKUINT(XFileExplorer::ID_RESTART,SEL_COMMAND),NULL);
+        	getApp()->reg().writeStringEntry("SETTINGS","font",fontspec.text());
+            mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RESTART),NULL);
+			getApp()->setNormalFont(nfont);
 		}
     }
     return 1;
@@ -296,18 +321,21 @@ long PreferencesBox::onCmdTextFont(FXObject*,FXSelector,void*)
 {
     FXFontDialog fontdlg(this,_("Change Text Font"),DECOR_BORDER|DECOR_TITLE);
     FXFontDesc fontdesc;
-    char fontspec[200];
-    fxparsefontdesc(fontdesc,getApp()->reg().readStringEntry("SETTINGS","textfont","[helvetica] 100 500 1 0 0 0"));
+	FXString fontspec;
+	fontspec=getApp()->reg().readStringEntry("SETTINGS","textfont","Helvetica,100,normal,regular");
+   	FXFont* tfont=new FXFont(getApp(),fontspec);
+	tfont->getFontDesc(fontdesc);
     fontdlg.setFontSelection(fontdesc);
     if(fontdlg.execute())
     {
         fontdlg.getFontSelection(fontdesc);
-        fxunparsefontdesc(fontspec,fontdesc);
+		tfont->setFontDesc(fontdesc);
+		fontspec=tfont->getFont();
         textfont->setText(fontspec);
-        if(MBOX_CLICKED_NO!=MessageBox::question(this,MBOX_YES_NO,_("Restart"),_("Text font will be changed after restart.\nRestart X File Explorer now?")))
+        if(MBOX_CLICKED_CANCEL!=MessageBox::question(this,MBOX_OK_CANCEL,_("Restart"),_("Text font will be changed after restart.\nRestart X File Explorer now?")))
 		{
-        	getApp()->reg().writeStringEntry("SETTINGS","textfont",fontspec);
-            getApp()->getMainWindow()->handle(this,MKUINT(XFileExplorer::ID_RESTART,SEL_COMMAND),NULL);
+        	getApp()->reg().writeStringEntry("SETTINGS","textfont",fontspec.text());
+            mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RESTART),NULL);
 		}
     }
     return 1;
@@ -335,12 +363,21 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
     confirm_overwrite=overwrite->getCheck();
     ask_before_copy=ask->getCheck();
     warn_if_root=root_warn->getCheck();
-
+#if defined(linux)
+	mount_warn=mount->getCheck();
+#endif
+	display_thumbnails=thumbnails->getCheck();
+	
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_quit",quit->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_delete",del->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","confirm_overwrite",overwrite->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","ask_before_copy",ask->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS","root_warn",root_warn->getCheck());
+#if defined(linux)
+    getApp()->reg().writeUnsignedEntry("OPTIONS","mount_warn",mount->getCheck());
+#endif
+    getApp()->reg().writeUnsignedEntry("OPTIONS","display_thumbnails",thumbnails->getCheck());
+
     if(currTheme != Themes[0])
     {
         getApp()->reg().writeColorEntry("SETTINGS","basecolor",currTheme.color[0]);
@@ -349,10 +386,10 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
         getApp()->reg().writeColorEntry("SETTINGS","forecolor",currTheme.color[3]);
         getApp()->reg().writeColorEntry("SETTINGS","selbackcolor",currTheme.color[4]);
         getApp()->reg().writeColorEntry("SETTINGS","selforecolor",currTheme.color[5]);
-        if(MBOX_CLICKED_NO!=MessageBox::question(this,MBOX_YES_NO,_("Restart"),_("Colors will be changed after restart.\nRestart X File Explorer now?")))
-            getApp()->getMainWindow()->handle(this,MKUINT(XFileExplorer::ID_RESTART,SEL_COMMAND),NULL);
+        if(MBOX_CLICKED_CANCEL!=MessageBox::question(this,MBOX_OK_CANCEL,_("Restart"),_("Colors will be changed after restart.\nRestart X File Explorer now?")))
+            mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RESTART),NULL);
     }
-    getApp()->getMainWindow()->handle(this,MKUINT(XFileExplorer::ID_RELOAD_PREFS,SEL_COMMAND),NULL);
+    mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_RELOAD_PREFS),NULL);
     FXDialogBox::onCmdAccept(o,s,p);
     return 1;
 }
