@@ -6,8 +6,6 @@
 // Number of themes
 #define THEMES_NUM 10
 
-class FXDialog;
-class FXApp;
 
 struct Theme
 {
@@ -60,6 +58,8 @@ private:
     FXCheckButton  *ask;
     FXCheckButton  *bg;
     FXCheckButton  *root_warn;
+    FXCheckButton  *mount;
+    FXCheckButton  *thumbnails;
     Theme          Themes[THEMES_NUM];
     Theme          currTheme;
 public:
