@@ -17,9 +17,9 @@
 #include <mntent.h>
 #endif
 
-#include <fox/fx.h>
-#include <fox/fxkeys.h>
-#include <fox/FXPNGIcon.h>
+#include <fox-1.2/fx.h>
+#include <fox-1.2/fxkeys.h>
+#include <fox-1.2/FXPNGIcon.h>
 
 #include "icons.h"
 #include "FileDialog.h"
@@ -43,6 +43,8 @@
 #endif
 
 
+// Global variables
+extern FXMainWindow *mainWindow;
 extern FXStringDict *devices;
 
 
@@ -59,32 +61,34 @@ PermFrame::PermFrame(FXComposite* parent,FXObject *target):
     FXHorizontalFrame *accessframe=new FXHorizontalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXHorizontalFrame *chmodframe=new FXHorizontalFrame(this,PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     FXGroupBox *group1=new FXGroupBox(accessframe,_("User"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
-    ur=new FXCheckButton(group1,_("Read"),target,S_IRUSR);
-    uw=new FXCheckButton(group1,_("Write"),target,S_IWUSR);
-    ux=new FXCheckButton(group1,_("Execute"),target,S_IXUSR);
-    FXGroupBox *group2=new FXGroupBox(accessframe,_("Group"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
-    gr=new FXCheckButton(group2,_("Read"),target,S_IRGRP);
-    gw=new FXCheckButton(group2,_("Write"),target,S_IWGRP);
-    gx=new FXCheckButton(group2,_("Execute"),target,S_IXGRP);
+    ur=new FXCheckButton(group1,_("Read"),target,PropertiesBox::ID_RUSR);
+    uw=new FXCheckButton(group1,_("Write"),target,PropertiesBox::ID_WUSR);
+    ux=new FXCheckButton(group1,_("Execute"),target,PropertiesBox::ID_XUSR);
+	FXGroupBox *group2=new FXGroupBox(accessframe,_("Group"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
+    gr=new FXCheckButton(group2,_("Read"),target,PropertiesBox::ID_RGRP);
+    gw=new FXCheckButton(group2,_("Write"),target,PropertiesBox::ID_WGRP);
+    gx=new FXCheckButton(group2,_("Execute"),target,PropertiesBox::ID_XGRP);
     FXGroupBox *group3=new FXGroupBox(accessframe,_("Others"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
-    or_=new FXCheckButton(group3,_("Read"),target,S_IROTH);
-    ow=new FXCheckButton(group3,_("Write"),target,S_IWOTH);
-    ox=new FXCheckButton(group3,_("Execute"),target,S_IXOTH);
+    or_=new FXCheckButton(group3,_("Read"),target,PropertiesBox::ID_ROTH);
+    ow=new FXCheckButton(group3,_("Write"),target,PropertiesBox::ID_WOTH);
+    ox=new FXCheckButton(group3,_("Execute"),target,PropertiesBox::ID_XOTH);
 
     FXGroupBox *group4=new FXGroupBox(chmodframe,_("Command"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-    set=new FXRadioButton(group4,_("Set marked"),target,PropertiesBox::ID_SET);
-    clear=new FXRadioButton(group4,_("Clear marked"),target,PropertiesBox::ID_CLEAR);
-    add=new FXRadioButton(group4,_("Add marked"),target,PropertiesBox::ID_ADD);
-
+	radiotarget.connect(cmd);
+	set=new FXRadioButton(group4,_("Set marked"),&radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_SET);
+    clear=new FXRadioButton(group4,_("Clear marked"),&radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_CLEAR);
+    add=new FXRadioButton(group4,_("Add marked"),&radiotarget,FXDataTarget::ID_OPTION+PropertiesBox::ID_ADD);
     rec=new FXCheckButton(group4,_("Recursive folders"),NULL,0);
     dironly=new FXCheckButton(group4,_("Folders only"),NULL,0);
     dironly->disable();
 
     FXGroupBox *group5=new FXGroupBox(chmodframe,_("Owner"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
     new FXLabel(group5,_("User"));
-    user=new FXComboBox(group5,10,5,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK);
+    user=new FXComboBox(group5,10,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK);
+  	user->setNumVisible(5);
     new FXLabel(group5,_("Group"));
-    grp=new FXComboBox(group5,10,5,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK);
+    grp=new FXComboBox(group5,10,NULL,0,COMBOBOX_NO_REPLACE|FRAME_SUNKEN|FRAME_THICK);
+  	grp->setNumVisible(5);
 
 	// User names (sorted in ascending order)
     struct passwd* pwde;
@@ -111,15 +115,15 @@ PermFrame::PermFrame(FXComposite* parent,FXObject *target):
 FXDEFMAP(PropertiesBox) PropertiesBoxMap[]={
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_SINGLE,PropertiesBox::onCmdAcceptSingle),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ACCEPT_MULT,PropertiesBox::onCmdAcceptMult),
-            FXMAPFUNC(SEL_COMMAND,S_IRUSR,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IWUSR,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IXUSR,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IRGRP,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IWGRP,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IXGRP,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IROTH,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IWOTH,PropertiesBox::onCmdCheck),
-            FXMAPFUNC(SEL_COMMAND,S_IXOTH,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_RUSR,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WUSR,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XUSR,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_RGRP,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WGRP,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XGRP,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_ROTH,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_WOTH,PropertiesBox::onCmdCheck),
+            FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_XOTH,PropertiesBox::onCmdCheck),
   			FXMAPFUNC(SEL_UPDATE,0,PropertiesBox::onUpdDironly),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_SET,PropertiesBox::onCmdCommand),
             FXMAPFUNC(SEL_COMMAND,PropertiesBox::ID_CLEAR,PropertiesBox::onCmdCommand),
@@ -138,17 +142,18 @@ FXIMPLEMENT(PropertiesBox,FXDialogBox,PropertiesBoxMap,ARRAYNUMBER(PropertiesBox
 // Construct window for one file
 PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER/*,0,0,350,200*/)
 {
-    unsigned long filesize;
-    char grpid[64],usrid[64],mod[32],changed[32],accessed[32];
+    unsigned long long filesize, dsize;
+    FXString mod,changed,accessed;
+	FXString grpid, usrid;
     struct stat info;
-    FXString extension;
+    FXString type, extension;
     int islink = 0;
 	int isdirectory = 0;
-    char filename[MAXPATHLEN+1],linkto[MAXPATHLEN+1],*e,name[MAXPATHLEN+1];
-	FILE *p;
+    char filename[MAXPATHLEN+1],linkto[MAXPATHLEN+1];
     char mnttype[64], used[64], avail[64], size[64];
     char buf[MAXPATHLEN+1];
 	FXbool ismountpoint=FALSE;
+	FILE *p;
 
     // Buttons
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
@@ -156,9 +161,6 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     // Contents
     FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);
 
-    // Cancel
-    new FXButton(buttons,_("&Cancel"),NULL,this,PropertiesBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
-
     // Accept
 	if (file!="..")
     {
@@ -166,6 +168,9 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     	ok->addHotKey(KEY_Return);
 	}
 
+    // Cancel
+    new FXButton(buttons,_("&Cancel"),NULL,this,PropertiesBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+
     // Switcher
     FXTabBook *tabbook = new FXTabBook(contents,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);
 
@@ -208,20 +213,20 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
     FXString viewlbl=_("View:");
     FXString editlbl=_("Edit:");
 
-    e = strrchr(file.text(),'.');
-    if(e)
-        if(!strcmp(e, ".gz") || !strcmp(e,".tgz") ||
-                !strcmp(e,".tar") || !strcmp(e,".bz2") ||
-                !strcmp(e,".zip") || !strcmp(e,"ZIP"))
-        {
-            is_ar = TRUE;// archive
-            viewlbl = _("Extract:");
-        }
+	extension=file.rafter('.',1);
+	if(extension=="gz" || extension=="GZ"  || extension=="tgz" || extension=="TGZ" ||
+		extension=="tar"|| extension=="TAR"|| extension=="bz2" || extension=="BZ2" ||
+		extension=="tbz2" || extension=="TBZ2" || extension=="zip" || extension=="ZIP" ||
+		extension=="Z")
+	{
+		is_ar = TRUE; // archive
+		viewlbl = _("Extract:");
+	}
 #if defined(linux)
-        else if(!strcmp(e,".rpm"))
-        {
-            editlbl = _("Install/Upgrade:");
-        }
+	else if(extension=="rpm")
+	{
+		editlbl = _("Install/Upgrade:");
+	}
 #endif
 
     new FXLabel(matrix,viewlbl,NULL,JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
@@ -250,18 +255,19 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 
     input = new FXTextField(generalframe,20,NULL,0,LAYOUT_SIDE_TOP|/*LAYOUT_CENTER_Y|*/LAYOUT_CENTER_X|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
 
-    strcpy(filename,(path+PATHSEPSTRING+file).text());
+    // Complete filename (with path)
+	strcpy(filename,(path+PATHSEPSTRING+file).text());
 	parentdir=path;
 	
     // Get file/link info
-    if(lstat(filename,&info)!=0)
+    if(lstatout(filename,&info)!=0)
         return ;
 
-    // Obtain user name
-    fxgetusername(usrid,info.st_uid);
+	// Obtain user name
+	usrid=FXFile::owner(info.st_uid);
 
-    // Obtain group name
-    fxgetgroupname(grpid,info.st_gid);
+	// Obtain group name
+	grpid=FXFile::group(info.st_gid);
     perm->user->setText(usrid);
     perm->grp->setText(grpid);
     oldgrp = grpid;
@@ -272,10 +278,10 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 	if(islink)
 	{
 		// If it is a broken link
-		if (stat(filename,&info)!=0)
-			extension="Broken link to ";
+		if (statout(filename,&info)!=0)
+			type="Broken link to ";
 		else
-			extension="Link to ";
+			type="Link to ";
 
 		// Get the name of the linked file
 		int nread;
@@ -287,24 +293,21 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 		}
 	}
 	else
-		extension="";
+		type="";
 
     orig_mode=(info.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO));
 
     // Mod time
-    strncpy(mod,ctime(&info.st_mtime)+4,20);
-    mod[20]=0;
+	mod=FXFile::time("%c",info.st_mtime);
 
     // Change time
-    strncpy(changed,ctime(&info.st_ctime)+4,20);
-    changed[20]=0;
+	changed=FXFile::time("%c",info.st_ctime);
 
     // Accessed time
-    strncpy(accessed,ctime(&info.st_atime)+4,20);
-    accessed[20]=0;
+    accessed=FXFile::time("%c",info.st_atime);;
 
     // Size
-    filesize=(unsigned long)info.st_size;
+    filesize=(unsigned long long)info.st_size;
     FXString fileassoc;
 
     // Is it a directory?
@@ -317,7 +320,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 		dupath=quote(dupath,FALSE);
 
 #if defined(linux)
-        FILE *mtab=setmntent("/etc/mtab","r");
+		FILE *mtab=setmntent("/etc/mtab","r");
         struct mntent *mnt;
         if(mtab)
         {
@@ -329,10 +332,8 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
                     {
                         ismountpoint=TRUE;
                         sprintf(buf,_("Filesystem (%s)"),mnt->mnt_fsname);
-                        extension+=buf;
+                        type+=buf;
 						strcpy(mnttype,mnt->mnt_type);
-						
-                        //sprintf(file_info,_("\nMount Type:          %s"),mnt->mnt_type);
                     }
                 }
             }
@@ -340,87 +341,75 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
         }
 #endif
 			// If it is a mount point
-            if(ismountpoint)
-            {
-                sprintf(buf,"df --block-size=1 %s",filename);
-                p=popen(buf,"r");
-                fgets(buf,sizeof(buf),p);
-                fgets(buf,sizeof(buf),p);
-                strtok(buf," "); // should check if str!=NULL
-                strtok(NULL," ");// get size
-                strcpy(used,strtok(NULL," "));// get used
-                strcpy(avail,strtok(NULL," "));// get available
-				pclose(p);
-            }
+		if(ismountpoint)
+		{
+			sprintf(buf,"df --block-size=1 %s",filename);
+			p=popen(buf,"r");
+			fgets(buf,sizeof(buf),p);
+			fgets(buf,sizeof(buf),p);
+			strtok(buf," "); // should check if str!=NULL
+			strtok(NULL," ");// get size
+			strcpy(used,strtok(NULL," "));// get used
+			strcpy(avail,strtok(NULL," "));// get available
+			pclose(p);
+		}
 			
-			// If it is a folder
-			else
-			{
-            	extension+=_("Folder");
-                sprintf(buf,"du --block-size=1 -s %s 2> /dev/null",dupath.text());
-    			getApp()->beginWaitCursor();
-				p=popen(buf,"r");
-                fgets(buf,sizeof(buf),p);
-                strcpy(size,strtok(buf,"\t"));
-				pclose(p);
-    			getApp()->endWaitCursor();
-			}
+		// If it is a folder
+		else
+		{
+            type+=_("Folder");
+    		getApp()->beginWaitCursor();
+			strcpy(buf,dupath.text());
+			dsize=dirpath(buf);
+			sprintf(size,"%llu",dsize);
+    		getApp()->endWaitCursor();
+		}
     }
 	
     else if(S_ISCHR(info.st_mode))
-        extension+="Character Device";
+        type+="Character Device";
     else if(S_ISBLK(info.st_mode))
-        extension+="Block Device";
+        type+="Block Device";
     else if(S_ISFIFO(info.st_mode))
-        extension+="Named Pipe";
+        type+="Named Pipe";
     else if(S_ISSOCK(info.st_mode))
-        extension+="Socket";
-    else // Regular file
+        type+="Socket";
+    
+	// Regular file or link
+	else
     {
-		// Try use association table	
-		strcpy(name,FXFile::name(filename).text());
-        fileassoc=getApp()->reg().readStringEntry("FILETYPES",name,"");
-        e = name;
-        if(fileassoc.empty())
-        {
-            e=strchr(name,'.');
-            while(e)
-            {
-                fileassoc = getApp()->reg().readStringEntry("FILETYPES",e+1,"");
-                if(!fileassoc.empty())
-                {
-                    e++;
-                    break;
-                }
-                e=strchr(e+1,'.');
-            }
-        }
+		// Try to use association table	
+		extension=FXFile::name(filename).rafter('.',1);
+        if (extension != "")
+			fileassoc=getApp()->reg().readStringEntry("FILETYPES",extension.text(),"");
 
 		// If we have an association
         if(!fileassoc.empty())
         {
             FXString c;
-            extension+=fileassoc.extract(1,';');
-            ext->setText(e);
+            type+=fileassoc.section(';',1);
+            ext->setText(extension);
             ext->disable();
-            c=fileassoc.extract(0,';');
-            descr->setText(fileassoc.extract(1,';'));
-            open->setText(c.extract(0,','));
-            view->setText(c.extract(1,','));
+            c=fileassoc.section(';',0);
+            descr->setText(fileassoc.section(';',1));
+            open->setText(c.section(',',0));
+            view->setText(c.section(',',1));
             if(edit)
-                edit->setText(c.extract(2,','));
-            bigic->setText(fileassoc.extract(2,';'));
-            miniic->setText(fileassoc.extract(3,';'));
+                edit->setText(c.section(',',2));
+            bigic->setText(fileassoc.section(';',2));
+            miniic->setText(fileassoc.section(';',3));
 
             fassoctab->enable();
         }
         else
         {
+            ext->setText(extension);
+            ext->disable();
             if(info.st_mode&(S_IXUSR|S_IXGRP|S_IXOTH))
-                extension+="Application";
+                type+="Application";
             else
             {
-                extension+="Document";
+                type+="Document";
                 fassoctab->enable();
             }
         }
@@ -493,7 +482,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 	}
 
     // File or mount type
-	fileType->setText(extension.text());
+	fileType->setText(type.text());
 
 	// If directory
 	if (isdirectory)
@@ -501,8 +490,8 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 		// if mount point
 		if(ismountpoint)
 		{
-			::Size(used,used);
-			::Size(avail,avail);
+			::hSize(used,used);
+			::hSize(avail,avail);
 			mtType->setText(mnttype);
 			mtUsed->setText(used);
 			mtFree->setText(avail);
@@ -513,24 +502,24 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
         	fileModified->setText(mod);
         	fileChanged->setText(changed);
         	fileAccessed->setText(accessed);
-			::Size(size,size);
+			::hSize(size,size);
 			fileSize->setText(size);
 		}
 	}
 	// Regular file
     else
     {
-        FXchar size[128], hsize[64];
-        sprintf(size,"%lu",filesize);
-        ::Size(size,hsize);
-        sprintf(size,"%s (%lu bytes)",hsize,filesize);        
+        FXchar size[64], hsize[64];
+        sprintf(size,"%llu",filesize);
+        ::hSize(size,hsize);
+        sprintf(size,"%s (%llu bytes)",hsize,filesize);        
 		fileSize->setText(size);
         fileModified->setText(mod);
         fileChanged->setText(changed);
         fileAccessed->setText(accessed);
     }
     mode = orig_mode;
-    command = PropertiesBox::ID_SET;//single file
+    perm->cmd=PropertiesBox::ID_SET;
     files = &file;
     source = file;
     num = 1;	
@@ -540,7 +529,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): FXDialo
 PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n): FXDialogBox(win,_("Properties"), DECOR_TITLE|DECOR_BORDER/*,0,0,350,200*/)
 {
 	struct stat info;
-	char grpid[64],usrid[64];
+	FXString grpid, usrid;
 
     // Buttons
     FXHorizontalFrame *buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
@@ -548,13 +537,13 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n): FXDialogBox(wi
     // Contents
     FXVerticalFrame *contents=new FXVerticalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);
 
-    // Cancel
-    new FXButton(buttons,_("&Cancel"),NULL,this,FXDialogBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
-
     // Accept
     FXButton *ok = new FXButton(buttons,_("&Accept"),NULL,this,PropertiesBox::ID_ACCEPT_MULT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
     ok->addHotKey(KEY_Return);
 
+    // Cancel
+    new FXButton(buttons,_("&Cancel"),NULL,this,FXDialogBox::ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y,0,0,0,0,20,20);
+
     // Switcher
     FXTabBook *tabbook = new FXTabBook(contents,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);
 
@@ -565,14 +554,14 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n): FXDialogBox(wi
 
     // Get file/link info of the first file of the list
 	// This is used as a guess for the username, group and permissions of the whole list
-    if(lstat(file[0].text(),&info)!=0)
+    if(lstatout(file[0].text(),&info)!=0)
         return ;
 
-    // Obtain user name
-    fxgetusername(usrid,info.st_uid);
+	// Obtain user name
+	usrid=FXFile::owner(info.st_uid);
 
-    // Obtain group name
-    fxgetgroupname(grpid,info.st_gid);
+	// Obtain group name
+	grpid=FXFile::group(info.st_gid);
 
     orig_mode=(info.st_mode & (S_IRWXU|S_IRWXG|S_IRWXO));
 
@@ -593,7 +582,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString *file,int n): FXDialogBox(wi
     perm->grp->setText(grpid);
 
     mode = orig_mode;
-    command = PropertiesBox::ID_ADD;
+    perm->cmd = PropertiesBox::ID_ADD;
     files = file;
     source = "";
     num = n;
@@ -615,10 +604,10 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
         {
             struct stat info;
             mode_t m;
-            if(lstat(files[i].text(),&info)!=0)
+            if(lstatout(files[i].text(),&info)!=0)
                 continue ;
 
-            switch(command)
+            switch(perm->cmd)
             {
             	case PropertiesBox::ID_ADD:
                 	m=info.st_mode|mode;
@@ -666,7 +655,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o,FXSelector s,void* p)
         for(i=0;i<num;i++)
         {
             struct stat info;
-            if(lstat(files[i].text(),&info)!=0)
+            if(lstatout(files[i].text(),&info)!=0)
                 continue ;
 
             uid_t uid = 32768;
@@ -737,21 +726,23 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
     fileassoc += descr->getText() + ";";
     fileassoc += bigic->getText() + ";" + miniic->getText() + ";;";
 
-    oldfileassoc=getApp()->reg().readStringEntry("FILETYPES",ext->getText().text(),"");
-    if(oldfileassoc == "" || fileassoc.extract(1,'=') != oldfileassoc)
-    {
-		FXString command=fileassoc.extract(1,'=');
-        getApp()->reg().writeStringEntry("FILETYPES",ext->getText().text(),command.text());
-
-		// Handle file association
-		str=new char*[2];
-		str[0]=new char[strlen(ext->getText().text())+1];
-		str[1]=new char[strlen(command.text())+1];
-		strcpy(str[0],ext->getText().text());
-		strcpy(str[1],command.text());
-		getApp()->getMainWindow()->handle(this,MKUINT(XFileExplorer::ID_FILE_ASSOC,SEL_COMMAND),str);
-    }
+	if (ext->getText()!="")
+	{
+		oldfileassoc=getApp()->reg().readStringEntry("FILETYPES",ext->getText().text(),"");
+    	if(oldfileassoc == "" || fileassoc.section('=',1) != oldfileassoc)
+    	{
+			FXString command=fileassoc.section('=',1);
+        	getApp()->reg().writeStringEntry("FILETYPES",ext->getText().text(),command.text());
 
+			// Handle file association
+			str=new char*[2];
+			str[0]=new char[strlen(ext->getText().text())+1];
+			str[1]=new char[strlen(command.text())+1];
+			strcpy(str[0],ext->getText().text());
+			strcpy(str[1],command.text());
+			mainWindow->handle(this,FXSEL(SEL_COMMAND,XFileExplorer::ID_FILE_ASSOC),str);
+    	}
+	}
     // Rename file
     FXString target=input->getText();
 	if(source != target)
@@ -793,17 +784,17 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 		input->setText(source);
 		return 1;
 	}
-    if(!(orig_mode == mode && command == PropertiesBox::ID_SET && !perm->rec->getCheck()))//no change
+    if(!(orig_mode == mode && perm->cmd == PropertiesBox::ID_SET && !perm->rec->getCheck()))//no change
     {
         f = new File(getApp(),_("File permissions"),CHMOD);
         f->create();
 
         struct stat info;
         mode_t m;
-        if(lstat(input->getText().text(),&info)!=0)
+        if(lstatout(input->getText().text(),&info)!=0)
             return 1;
 
-        switch(command)
+        switch(perm->cmd)
         {
         	case PropertiesBox::ID_ADD:
             	m=info.st_mode|mode;
@@ -817,7 +808,6 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
         	default :
             	return 1;
         }
-
 		// Perform chmod on the selected file or directory
 		rc=f->chmod(strdup(input->getText().text()),file,m,perm->rec->getCheck(),perm->dironly->getCheck());
 
@@ -879,19 +869,51 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o,FXSelector s,void* p)
 
 long PropertiesBox::onCmdCommand(FXObject* o,FXSelector s,void* p)
 {
-    command = SELID(s);
+    perm->cmd = FXSELID(s);
     return 1;
 }
 
 
 long PropertiesBox::onCmdCheck(FXObject* o,FXSelector s,void* p)
 {
-    FXCheckButton* ch = (FXCheckButton*)o;
-    if(!ch->getCheck())
-        mode = mode & ~SELID(s);
+    FXint xmode=0;
+	switch (FXSELID(s))
+	{
+		case PropertiesBox::ID_RUSR:
+			xmode=S_IRUSR;
+			break;
+		case PropertiesBox::ID_WUSR:
+			xmode=S_IWUSR;
+			break;
+		case PropertiesBox::ID_XUSR:
+			xmode=S_IXUSR;
+			break;
+		case PropertiesBox::ID_RGRP:
+			xmode=S_IRGRP;
+			break;
+		case PropertiesBox::ID_WGRP:
+			xmode=S_IWGRP;
+			break;
+		case PropertiesBox::ID_XGRP:
+			xmode=S_IXGRP;
+			break;
+		case PropertiesBox::ID_ROTH:
+			xmode=S_IROTH;
+			break;
+		case PropertiesBox::ID_WOTH:
+			xmode=S_IWOTH;
+			break;
+		case PropertiesBox::ID_XOTH:
+			xmode=S_IXOTH;
+			break;
+	}
+	FXCheckButton* ch = (FXCheckButton*)o;    
+	if(!ch->getCheck())
+       mode &= ~xmode;
     else
-        mode |= SELID(s);
+        mode |= xmode;
     return 1;
+
 }
 
 
@@ -906,7 +928,7 @@ long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
     if(browseProgram.execute())
     {
         char *path=strdup(browseProgram.getFilename().text());
-        switch(SELID(s))
+        switch(FXSELID(s))
         {
         	case ID_BROWSE_OPEN:
             	open->setText(FXFile::name(path).text());
@@ -927,7 +949,7 @@ long PropertiesBox::onCmdBrowse(FXObject* o,FXSelector s,void* p)
 long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
 {
     FXString icon;
-    if(SELID(s)==ID_BIG_ICON)
+    if(FXSELID(s)==ID_BIG_ICON)
         icon = bigic->getText();
     else
         icon= miniic->getText();
@@ -935,8 +957,8 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
 	FXString iconpath=getApp()->reg().readStringEntry("SETTINGS","iconpath","/usr/lib/foxicons");
     const FXchar *patterns[]=
         {
-            _("GIF Images"),     "*.gif",
             _("PNG Images"),     "*.png",
+			_("GIF Images"),     "*.gif",
             _("BMP Images"),     "*.bmp",NULL
         };
     FileDialog browseIcon(this,_("Select Icon"));
@@ -947,10 +969,10 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* o,FXSelector s,void* p)
         char *path=strdup(browseIcon.getFilename().text());
         if(!exists(dequote(path)))
             return 0;
-        if(SELID(s)==ID_BIG_ICON)
-            bigic->setText(FXFile::name(path).text());
+        if(FXSELID(s)==ID_BIG_ICON)
+            bigic->setText(path);
         else
-            miniic->setText(FXFile::name(path).text());
+            miniic->setText(path);
     }
     return 1;
 }
@@ -971,11 +993,11 @@ long PropertiesBox::onCmdKeyPress(FXObject* sender,FXSelector sel,void* ptr)
     switch(event->code)
     {
     case KEY_Escape:
-        handle(this,MKUINT(ID_CANCEL,SEL_COMMAND),NULL);
+        handle(this,FXSEL(SEL_COMMAND,ID_CANCEL),NULL);
 		return 1;
     case KEY_KP_Enter:
     case KEY_Return:
-        handle(this,MKUINT(ID_ACCEPT_SINGLE,SEL_COMMAND),NULL);
+        handle(this,FXSEL(SEL_COMMAND,ID_ACCEPT_SINGLE),NULL);
 		return 1;
     default:
         FXTopWindow::onKeyPress(sender,sel,ptr);
