@@ -1,9 +1,6 @@
 #ifndef PROPERTIES_H
 #define PROPERTIES_H
 
-
-class FXDialog;
-class FXApp;
 class PropertiesBox;
 
 class PermFrame : public FXVerticalFrame
@@ -13,26 +10,29 @@ class PermFrame : public FXVerticalFrame
 private:
     PermFrame()
     {}
-    FXCheckButton*    ur;
-    FXCheckButton*    uw;
-    FXCheckButton*    ux;
-    FXCheckButton*    gr;
-    FXCheckButton*    gw;
-    FXCheckButton*    gx;
-    FXCheckButton*    or_;
-    FXCheckButton*    ow;
-    FXCheckButton*    ox;
-    FXRadioButton*    add;
-    FXRadioButton*    clear;
-    FXRadioButton*    set;
-    FXCheckButton*    rec;
-    FXCheckButton*    dironly;
-    FXComboBox*       user;
-    FXComboBox*       userbis;
-    FXComboBox*       grp;
+    FXCheckButton*	ur;
+    FXCheckButton*	uw;
+    FXCheckButton*	ux;
+    FXCheckButton*	gr;
+    FXCheckButton*	gw;
+    FXCheckButton*	gx;
+    FXCheckButton*	or_;
+    FXCheckButton*	ow;
+    FXCheckButton*	ox;
+	FXDataTarget	radiotarget;
+	FXRadioButton*	set;
+	FXRadioButton*	clear;
+	FXRadioButton*	add;
+	FXint			cmd;		  
+    FXCheckButton*	rec;
+    FXCheckButton*	dironly;
+    FXComboBox*		user;
+    FXComboBox*		userbis;
+    FXComboBox*		grp;
 public:
     PermFrame(FXComposite *parent,FXObject *target);
 };
+
 class PropertiesBox : public FXDialogBox
 {
     FXDECLARE(PropertiesBox)
@@ -67,13 +67,12 @@ private:
     FXTextField		*bigic;
     FXTextField		*miniic;
     FXTextField		*test;
-    mode_t	mode;
-    mode_t	orig_mode;
-    int	command;
+    mode_t			mode;
+    mode_t			orig_mode;
     PermFrame *perm;
 public:
     enum{
-        ID_ACCEPT_SINGLE=FXDialogBox::ID_LAST, // 55
+        ID_ACCEPT_SINGLE=FXDialogBox::ID_LAST,
         ID_ACCEPT_MULT,
         ID_SET,
         ID_CLEAR,
@@ -82,10 +81,16 @@ public:
         ID_MINI_ICON,
         ID_BROWSE_OPEN,
         ID_BROWSE_VIEW,
-// Ugly hack : the 64 value doesn'work, why ??? 
-        ID_DUMMY,  // 64
-// To be debugged some day!!!
         ID_BROWSE_EDIT,
+		ID_RUSR,
+        ID_WUSR,
+        ID_XUSR,
+        ID_RGRP,
+        ID_WGRP,
+        ID_XGRP,
+        ID_ROTH,
+        ID_WOTH,
+        ID_XOTH,
         ID_LAST
     };
 
