@@ -1,4 +1,4 @@
-#include <fox/fx.h>
+#include <fox-1.2/fx.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -6,11 +6,11 @@ class XFileQuery : public FXMainWindow
 {
     FXDECLARE(XFileQuery)
 protected:
-    FXMenubar			*menubar;			// Menu bar
+    FXMenuBar			*menubar;			// Menu bar
     FXMenuPane			*filemenu;			// File menu
     FXMenuPane			*helpmenu;			// Help menu
     FXHorizontalFrame	*contents;			// Sunken border for text widget
-    FXHorizontalFrame	*toolbar;			// Toolbar
+    FXToolBar			*toolbar;			// Toolbar
     FXString 			filename;			// Current package name
     FXTreeList 			*list;				// File list
     FXText 				*description;		// Package description
@@ -32,8 +32,9 @@ public:
         ID_QUIT,
         ID_LAST
     };
+    void start(int& argc,char** argv);
     void create();
-    XFileQuery(FXApp *a, char *file);
+    XFileQuery(FXApp *a);
     long onCmdUninstall(FXObject*,FXSelector,void*);
     long onCmdUpgrade(FXObject*,FXSelector,void*);
 	long onCmdAbout(FXObject*,FXSelector,void*);
