@@ -5,13 +5,13 @@ class XFileView : public FXMainWindow
 {
     FXDECLARE(XFileView)
 protected:
-    FXMenubar			*menubar;			// Menu bar
+    FXMenuBar			*menubar;			// Menu bar
     FXMenuPane			*filemenu;			// File menu
     FXMenuPane			*helpmenu;			// Help menu
     FXHorizontalFrame	*contents;			// Sunken border for text widget
-    FXHorizontalFrame	*toolbar;			// Tool bar
+    FXToolBar			*toolbar;			// Toolbar
     FXText				*viewer;			// Multiline text widget
-    FXStatusbar			*statusbar;			// Status bar
+    FXStatusBar			*statusbar;			// Status bar
     FXString			filename;			// File being edited
     FXTextField			*text;
 protected:
